@@ -2,7 +2,7 @@
 	/**
 	 * Class to hold various commonly used functions
 	 *
-	 * $Id: Misc.php,v 1.113.2.3 2005/11/19 09:17:23 chriskl Exp $
+	 * $Id: Misc.php,v 1.137 2006/12/28 04:26:55 xzilla Exp $
 	 */
 	 
 	class Misc {
@@ -172,6 +172,49 @@
 				case 'callback':
 					$out = $params['function']($str, $params);
 					break;
+				case 'prettysize':
+					$mult = 1;
+					$limit = 10 * 1024;
+
+					if ($str < $limit * $mult)
+						$out = $str.' '.$lang['strbytes'];
+					else
+					{
+						$mult *= 1024;
+						if ($str < $limit * $mult)
+							$out = floor(($str + $mult / 2) / $mult).' '.$lang['strkb'];
+						else
+						{ 							
+							$mult *= 1024;
+							if ($str < $limit * $mult)
+								$out = floor(($str + $mult / 2) / $mult).' '.$lang['strmb'];
+							else
+							{ 							
+								$mult *= 1024;
+								if ($str < $limit * $mult)
+									$out = floor(($str + $mult / 2) / $mult).' '.$lang['strgb'];
+								else
+								{ 							
+									$mult *= 1024;
+									if ($str < $limit * $mult)
+										$out = floor(($str + $mult / 2) / $mult).' '.$lang['strtb'];
+								}
+							}
+						}
+					}
+					break;
+				case 'slonystatus':
+					switch ($str) {
+					case 'insync':
+						$out = $lang['strhealthy'];
+						break;
+					case 'outofsync':
+						$out = $lang['stroutofsync'];
+						break;
+					default:
+						$out = $lang['strunknown'];
+					}
+					break;
 				default:
 					// If the string contains at least one instance of >1 space in a row, a tab
 					// character, a space at the start of a line, or a space at the start of
@@ -254,7 +297,7 @@
 		 * Creates a database accessor
 		 */
 		function getDatabaseAccessor($database, $server_id = null) {
-			global $lang, $conf, $misc;
+			global $lang, $conf, $misc, $_connection;
 			
 			$server_info = $this->getServerInfo($server_id);
 
@@ -278,6 +321,7 @@
 			$_connection = new Connection(
 				$server_info['host'],
 				$server_info['port'],
+				$server_info['sslmode'],
 				$server_info['username'],
 				$server_info['password'],
 				$database
@@ -393,22 +437,12 @@
 			global $misc, $conf, $data, $lang;
 			
 			if (is_string($tabs)) {
-				switch ($tabs) {
-					case 'database':
-					case 'schema':
-						if ($data->hasSchemas() === false) {
-							$this->printTabs($this->getNavTabs('database'), $activetab);
-							$this->printTabs($this->getNavTabs('schema'), $activetab);
-							$_SESSION['webdbLastTab']['database'] = $activetab;
-							return;
-						}
-					default:
-						$_SESSION['webdbLastTab'][$tabs] = $activetab;
-						$tabs = $this->getNavTabs($tabs);
-				}
+				$_SESSION['webdbLastTab'][$tabs] = $activetab;
+				$tabs = $this->getNavTabs($tabs);
 			}
 			
 			echo "<table class=\"tabs\"><tr>\n";
+			#echo "<div class=\"tabs\">\n";
 			
 			# FIXME: don't count hidden tags
 			$width = round(100 / count($tabs)).'%';
@@ -417,9 +451,16 @@
 				$active = ($tab_id == $activetab) ? ' active' : '';
 				
 				if (!isset($tab['hide']) || $tab['hide'] !== true) {
-					$tablink = "<a" . $this->printActionUrl($tab, $_REQUEST, 'href') . ">{$tab['title']}</a>";
+					
+					$tablink = "<a" . $this->printActionUrl($tab, $_REQUEST, 'href') . ">";
+					
+					if (isset($tab['icon']) && $icon = $this->icon($tab['icon']))
+						$tablink .= "<span class=\"icon\"><img src=\"{$icon}\" alt=\"{$tab['title']}\" /></span>";
+					
+					$tablink .= "<span class=\"label\">{$tab['title']}</span></a>";
 					
 					echo "<td width=\"{$width}\" class=\"tab{$active}\">";
+					#echo "<span class=\"tab{$active}\" style=\"white-space:nowrap;\">";
 					
 					if (isset($tab['help']))
 						$this->printHelp($tablink, $tab['help']);
@@ -427,10 +468,12 @@
 						echo $tablink;
 					
 					echo "</td>\n";
+					#echo "</span>\n";
 				}
 			}
 			
 			echo "</tr></table>\n";
+			#echo "</div>\n";
 		}
 
 		/**
@@ -448,43 +491,68 @@
 						'intro' => array (
 							'title' => $lang['strintroduction'],
 							'url'   => "intro.php",
+							'icon'  => 'Introduction',
 						),
 						'servers' => array (
 							'title' => $lang['strservers'],
 							'url'   => "servers.php",
+							'icon'  => 'Servers',
 						),
 					);
 
 				case 'server':
 					$server_info = $this->getServerInfo();
 					$hide_users = !$data->isSuperUser($server_info['username']);
-					return array (
+					$tmp = array (
 						'databases' => array (
 							'title' => $lang['strdatabases'],
 							'url'   => 'all_db.php',
 							'urlvars' => array('subject' => 'server'),
 							'help'  => 'pg.database',
-						),
-						'users' => array (
-							'title' => $lang['strusers'],
-							'url'   => 'users.php',
-							'urlvars' => array('subject' => 'server'),
-							'hide'  => $hide_users,
-							'help'  => 'pg.user',
-						),
-						'groups' => array (
-							'title' => $lang['strgroups'],
-							'url'   => 'groups.php',
-							'urlvars' => array('subject' => 'server'),
-							'hide'  => $hide_users,
-							'help'  => 'pg.group',
-						),
+							'icon'  => 'Databases',
+						)
+					);
+					if ($data->hasRoles()) {
+						$tmp = array_merge($tmp, array(
+							'roles' => array (
+								'title' => $lang['strroles'],
+								'url'   => 'roles.php',
+								'urlvars' => array('subject' => 'server'),
+								'hide'  => $hide_users,
+								'help'  => 'pg.role',
+								'icon'  => 'Roles',
+							)
+						));
+					}
+					else {
+						$tmp = array_merge($tmp, array(
+							'users' => array (
+								'title' => $lang['strusers'],
+								'url'   => 'users.php',
+								'urlvars' => array('subject' => 'server'),
+								'hide'  => $hide_users,
+								'help'  => 'pg.user',
+								'icon'  => 'Users',
+							),
+							'groups' => array (
+								'title' => $lang['strgroups'],
+								'url'   => 'groups.php',
+								'urlvars' => array('subject' => 'server'),
+								'hide'  => $hide_users,
+								'help'  => 'pg.group',
+								'icon'  => 'UserGroups',
+							)
+						));
+					}
+					
+					$tmp = array_merge($tmp, array(							
 						'account' => array (
 							'title' => $lang['straccount'],
-							'url'   => 'users.php',
+							'url'   => $data->hasRoles() ? 'roles.php' : 'users.php',
 							'urlvars' => array('subject' => 'server', 'action' => 'account'),
 							'hide'  => !$hide_users,
-							'help'  => 'pg.user',
+							'help'  => 'pg.role',
+							'icon'  => 'User',
 						),
 						'tablespaces' => array (
 							'title' => $lang['strtablespaces'],
@@ -492,22 +560,26 @@
 							'urlvars' => array('subject' => 'server'),
 							'hide'  => (!$data->hasTablespaces()),
 							'help'  => 'pg.tablespace',
+							'icon'  => 'Tablespaces',
 						),
 						'export' => array (
 							'title' => $lang['strexport'],
 							'url'   => 'all_db.php',
 							'urlvars' => array('subject' => 'server', 'action' => 'export'),
 							'hide'  => (!$this->isDumpEnabled()),
+							'icon'  => 'Export',
 						),
 						'reports' => array (
 							'title' => $lang['strreports'],
 							'url'   => 'reports.php',
 							'urlvars' => array('subject' => 'server'),
-							'hide' => !$conf['show_reports']
-						),
-					);
-
-				case 'database':				
+							'hide' => !$conf['show_reports'],
+							'icon' => 'Reports',
+						)
+					));
+					return $tmp;
+					break;
+				case 'database':
 					$tabs = array (
 						'schemas' => array (
 							'title' => $lang['strschemas'],
@@ -515,6 +587,7 @@
 							'urlvars' => array('subject' => 'database'),
 							'hide'  => (!$data->hasSchemas()),
 							'help'  => 'pg.schema',
+							'icon'  => 'Schemas',
 						),
 						'sql' => array (
 							'title' => $lang['strsql'],
@@ -522,12 +595,14 @@
 							'urlvars' => array('subject' => 'database', 'action' => 'sql'),
 							'help'  => 'pg.sql',
 							'tree'  => false,
+							'icon'  => 'SqlEditor'
 						),
 						'find' => array (
 							'title' => $lang['strfind'],
 							'url'   => 'database.php',
 							'urlvars' => array('subject' => 'database', 'action' => 'find'),
 							'tree'  => false,
+							'icon'  => 'Search'
 						),
 						'variables' => array (
 							'title' => $lang['strvariables'],
@@ -536,6 +611,7 @@
 							'hide'  => (!$data->hasVariables()),
 							'help'  => 'pg.variable',
 							'tree'  => false,
+							'icon'  => 'Variables',
 						),
 						'processes' => array (
 							'title' => $lang['strprocesses'],
@@ -544,12 +620,23 @@
 							'hide'  => (!$data->hasProcesses()),
 							'help'  => 'pg.process',
 							'tree'  => false,
+							'icon'  => 'Processes',
+						),
+						'locks' => array (
+							'title' => $lang['strlocks'],
+							'url'   => 'database.php',
+							'urlvars' => array('subject' => 'database', 'action' => 'locks'),
+							'hide'  => (!$data->hasLocksView()),
+							'help'  => 'pg.locks',
+							'tree'  => false,
+							'icon'  => 'Key',
 						),
 						'admin' => array (
 							'title' => $lang['stradmin'],
 							'url'   => 'database.php',
 							'urlvars' => array('subject' => 'database', 'action' => 'admin'),
 							'tree'  => false,
+							'icon'  => 'Admin',
 						),
 						'privileges' => array (
 							'title' => $lang['strprivileges'],
@@ -558,6 +645,7 @@
 							'hide'  => (!isset($data->privlist['database'])),
 							'help'  => 'pg.privilege',
 							'tree'  => false,
+							'icon'  => 'Privileges',
 						),
 						'languages' => array (
 							'title' => $lang['strlanguages'],
@@ -565,6 +653,7 @@
 							'urlvars' => array('subject' => 'database'),
 							'hide'  => $hide_advanced,
 							'help'  => 'pg.language',
+							'icon'  => 'Languages',
 						),
 						'casts' => array (
 							'title' => $lang['strcasts'],
@@ -572,6 +661,7 @@
 							'urlvars' => array('subject' => 'database'),
 							'hide'  => ($hide_advanced || !$data->hasCasts()),
 							'help'  => 'pg.cast',
+							'icon'  => 'Casts',
 						),
 						'slony' => array (
 							'title' => 'Slony',
@@ -579,6 +669,7 @@
 							'urlvars' => array('subject' => 'database', 'action' => 'clusters_properties'),
 							'hide'  => !isset($slony),
 							'help'  => '',
+							'icon'  => 'Replication',
 						),
 						'export' => array (
 							'title' => $lang['strexport'],
@@ -586,9 +677,11 @@
 							'urlvars' => array('subject' => 'database', 'action' => 'export'),
 							'hide'  => (!$this->isDumpEnabled()),
 							'tree'  => false,
+							'icon'  => 'Export',
 						),
 					);
 					return $tabs;
+
 				case 'schema':
 					return array (
 						'tables' => array (
@@ -596,28 +689,28 @@
 							'url'   => 'tables.php',
 							'urlvars' => array('subject' => 'schema'),
 							'help'  => 'pg.table',
-							'icon'  => 'tables',
+							'icon'  => 'Tables',
 						),
 						'views' => array (
 							'title' => $lang['strviews'],
 							'url'   => 'views.php',
 							'urlvars' => array('subject' => 'schema'),
 							'help'  => 'pg.view',
-							'icon'  => 'views',
+							'icon'  => 'Views',
 						),
 						'sequences' => array (
 							'title' => $lang['strsequences'],
 							'url'   => 'sequences.php',
 							'urlvars' => array('subject' => 'schema'),
 							'help'  => 'pg.sequence',
-							'icon'  => 'sequences',
+							'icon'  => 'Sequences',
 						),
 						'functions' => array (
 							'title' => $lang['strfunctions'],
 							'url'   => 'functions.php',
 							'urlvars' => array('subject' => 'schema'),
 							'help'  => 'pg.function',
-							'icon'  => 'functions',
+							'icon'  => 'Functions',
 						),
 						'domains' => array (
 							'title' => $lang['strdomains'],
@@ -625,7 +718,7 @@
 							'urlvars' => array('subject' => 'schema'),
 							'hide'  => (!$data->hasDomains()),
 							'help'  => 'pg.domain',
-							'icon'  => 'domains',
+							'icon'  => 'Domains',
 						),
 						'aggregates' => array (
 							'title' => $lang['straggregates'],
@@ -633,7 +726,7 @@
 							'urlvars' => array('subject' => 'schema'),
 							'hide'  => $hide_advanced,
 							'help'  => 'pg.aggregate',
-							'icon'  => 'functions',
+							'icon'  => 'Aggregates',
 						),
 						'types' => array (
 							'title' => $lang['strtypes'],
@@ -641,7 +734,7 @@
 							'urlvars' => array('subject' => 'schema'),
 							'hide'  => $hide_advanced,
 							'help'  => 'pg.type',
-							'icon'  => 'types',
+							'icon'  => 'Types',
 						),
 						'operators' => array (
 							'title' => $lang['stroperators'],
@@ -649,7 +742,7 @@
 							'urlvars' => array('subject' => 'schema'),
 							'hide'  => $hide_advanced,
 							'help'  => 'pg.operator',
-							'icon'  => 'operators',
+							'icon'  => 'Operators',
 						),
 						'opclasses' => array (
 							'title' => $lang['stropclasses'],
@@ -657,7 +750,7 @@
 							'urlvars' => array('subject' => 'schema'),
 							'hide'  => $hide_advanced,
 							'help'  => 'pg.opclass',
-							'icon'  => 'operators',
+							'icon'  => 'OperatorClasses',
 						),
 						'conversions' => array (
 							'title' => $lang['strconversions'],
@@ -665,7 +758,7 @@
 							'urlvars' => array('subject' => 'schema'),
 							'hide'  => ($hide_advanced || !$data->hasConversions()),
 							'help'  => 'pg.conversion',
-							'icon'  => 'types',
+							'icon'  => 'Conversions',
 						),
 						'privileges' => array (
 							'title' => $lang['strprivileges'],
@@ -674,6 +767,7 @@
 							'hide'  => (!$data->hasSchemas()),
 							'help'  => 'pg.privilege',
 							'tree'  => false,
+							'icon'  => 'Privileges',
 						),
 					);
 
@@ -683,51 +777,60 @@
 							'title' => $lang['strcolumns'],
 							'url'   => 'tblproperties.php',
 							'urlvars' => array('subject' => 'table', 'table' => field('table')),
+							'icon'  => 'Columns',
 						),
 						'indexes' => array (
 							'title' => $lang['strindexes'],
 							'url'   => 'indexes.php',
 							'urlvars' => array('subject' => 'table', 'table' => field('table')),
 							'help'  => 'pg.index',
+							'icon'  => 'Indexes',
 						),
 						'constraints' => array (
 							'title' => $lang['strconstraints'],
 							'url'   => 'constraints.php',
 							'urlvars' => array('subject' => 'table', 'table' => field('table')),
 							'help'  => 'pg.constraint',
+							'icon'  => 'Constraints',
 						),
 						'triggers' => array (
 							'title' => $lang['strtriggers'],
 							'url'   => 'triggers.php',
 							'urlvars' => array('subject' => 'table', 'table' => field('table')),
 							'help'  => 'pg.trigger',
+							'icon'  => 'Triggers',
 						),
 						'rules' => array (
 							'title' => $lang['strrules'],
 							'url'   => 'rules.php',
 							'urlvars' => array('subject' => 'table', 'table' => field('table')),
 							'help'  => 'pg.rule',
+							'icon'  => 'Rules',
 						),
 						'info' => array (
 							'title' => $lang['strinfo'],
 							'url'   => 'info.php',
 							'urlvars' => array('subject' => 'table', 'table' => field('table')),
+							'icon'  => 'Statistics',
 						),
 						'privileges' => array (
 							'title' => $lang['strprivileges'],
 							'url'   => 'privileges.php',
 							'urlvars' => array('subject' => 'table', 'table' => field('table')),
 							'help'  => 'pg.privilege',
+							'icon'  => 'Privileges',
 						),
 						'import' => array (
 							'title' => $lang['strimport'],
 							'url'   => 'tblproperties.php',
 							'urlvars' => array('subject' => 'table', 'table' => field('table'), 'action' => 'import'),
+							'icon'  => 'Import',
 						),
 						'export' => array (
 							'title' => $lang['strexport'],
 							'url'   => 'tblproperties.php',
 							'urlvars' => array('subject' => 'table', 'table' => field('table'), 'action' => 'export'),
+							'icon'  => 'Export',
 						),
 					);
 				
@@ -737,28 +840,33 @@
 							'title' => $lang['strcolumns'],
 							'url'   => 'viewproperties.php',
 							'urlvars' => array('subject' => 'view', 'view' => field('view')),
+							'icon'  => 'Columns',
 						),
 						'definition' => array (
 							'title' => $lang['strdefinition'],
 							'url'   => 'viewproperties.php',
 							'urlvars' => array('subject' => 'view', 'view' => field('view'), 'action' => 'definition'),
+							'icon'  => 'Definition'
 						),
 						'rules' => array (
 							'title' => $lang['strrules'],
 							'url'   => 'rules.php',
 							'urlvars' => array('subject' => 'view', 'view' => field('view')),
 							'help'  => 'pg.rule',
+							'icon'  => 'Rules',
 						),
 						'privileges' => array (
 							'title' => $lang['strprivileges'],
 							'url'   => 'privileges.php',
 							'urlvars' => array('subject' => 'view', 'view' => field('view')),
 							'help'  => 'pg.privilege',
+							'icon'  => 'Privileges',
 						),
 						'export' => array (
 							'title' => $lang['strexport'],
 							'url'   => 'viewproperties.php',
 							'urlvars' => array('subject' => 'view', 'view' => field('view'), 'action' => 'export'),
+							'icon'  => 'Export',
 						),
 					);
 				
@@ -773,6 +881,7 @@
 									'function_oid' => field('function_oid'),
 									'action' => 'properties',
 								),
+							'icon'  => 'Definition',
 						),
 						'privileges' => array (
 							'title' => $lang['strprivileges'],
@@ -782,9 +891,39 @@
 									'function' => field('function'),
 									'function_oid' => field('function_oid'),
 								),
+							'icon'  => 'Privileges',
 						),
 					);
-				
+					
+				case 'aggregate':
+					return array (
+						'definition' => array (
+							'title' => $lang['strdefinition'],
+							'url'   => 'aggregates.php',
+							'urlvars' => array(
+									'subject' => 'aggregate',
+									'aggrname' => field('aggrname'),
+									'aggrtype' => field('aggrtype'),
+									'action' => 'properties',
+								),
+							'icon'  => 'Definition',
+						),
+					);
+
+				case 'role':
+					return array (
+						'definition' => array (
+							'title' => $lang['strdefinition'],
+							'url'   => 'roles.php',
+							'urlvars' => array(
+									'subject' => 'role',
+									'rolename' => field('rolename'),
+									'action' => 'properties',
+								),
+							'icon'  => 'Definition',
+						),
+					);
+			
 				case 'popup':
 					return array (
 						'sql' => array (
@@ -792,11 +931,13 @@
 							'url'   => 'sqledit.php',
 							'urlvars' => array('subject' => 'schema', 'action' => 'sql'),
 							'help'  => 'pg.sql',
+							'icon'  => 'SqlEditor',
 						),
 						'find' => array (
 							'title' => $lang['strfind'],
 							'url'   => 'sqledit.php',
 							'urlvars' => array('subject' => 'schema', 'action' => 'find'),
+							'icon'  => 'Search',
 						),
 					);
 				
@@ -811,6 +952,8 @@
 									'slony_cluster' => field('slony_cluster')
 								),
 							'help'  => '',
+							'tree'  => false,
+							'icon'  => 'Cluster',
 						),
 						'nodes' => array (
 							'title' => $lang['strnodes'],
@@ -820,7 +963,9 @@
 									'action' => 'nodes_properties',
 									'slony_cluster' => field('slony_cluster')
 								),
+							'branch' => 'nodes',
 							'help'  => '',
+							'icon'  => 'Nodes',
 						),
 						'sets' => array (
 							'title' => $lang['strrepsets'],
@@ -830,9 +975,21 @@
 									'action' => 'sets_properties',
 									'slony_cluster' => field('slony_cluster')
 								),
+							'branch' => 'sets',
 							'help'  => '',
+							'icon'  => 'ReplicationSets',
 						),
 					);
+
+				case 'column':
+					return array(
+						'properties' => array (
+							'title'		=> $lang['strcolprop'],
+							'url'		=> 'colproperties.php',
+							'urlvars'	=> array('subject' => 'column', 'table' => field('table'), 'column' => field('column')),
+							'icon'		=> 'Column'
+						)
+					);
 					
 				default:
 					return array();
@@ -844,9 +1001,10 @@
 		 */
 		function getLastTabURL($section) {
 			global $data;
-			
+
 			switch ($section) {
 				case 'database':
+				case 'role':
 				case 'schema':
 					if ($data->hasSchemas() === false) {
 						$section = 'database';
@@ -856,7 +1014,7 @@
 				default:
 					$tabs = $this->getNavTabs($section);
 			}
-			
+		
 			if (isset($_SESSION['webdbLastTab'][$section]) && isset($tabs[$_SESSION['webdbLastTab'][$section]]))
 				$tab = $tabs[$_SESSION['webdbLastTab'][$section]];
 			else
@@ -875,7 +1033,7 @@
 			if ($server_info && isset($server_info['platform']) && isset($server_info['username'])) {
 				echo sprintf($lang['strtopbar'],
 					'<span class="platform">'.htmlspecialchars($server_info['platform']).'</span>',
-					'<span class="host">'.htmlspecialchars($server_info['host']).'</span>',
+					'<span class="host">'.htmlspecialchars((empty($server_info['host'])) ? 'localhost':$server_info['host']).'</span>',
 					'<span class="port">'.htmlspecialchars($server_info['port']).'</span>',
 					'<span class="username">'.htmlspecialchars($server_info['username']).'</span>',
 					'<span class="date">'.date($lang['strtimefmt']).'</span>');
@@ -896,7 +1054,7 @@
 				
 				echo "<a class=\"toplink\" href=\"{$url}find\" target=\"sqledit\" onclick=\"window.open('{$url}find','{$window_id}','toolbar=no,width=600,height=400,resizable=yes,scrollbars=no').focus(); return false;\">{$lang['strfind']}</a> | ";
 				
-				echo "<a class=\"toplink\" href=\"servers.php?action=logout&amp;logoutServer=".htmlspecialchars($server_info['host']).":".htmlspecialchars($server_info['port'])."\">{$lang['strlogout']}</a>";
+ 				echo "<a class=\"toplink\" href=\"servers.php?action=logout&amp;logoutServer=".htmlspecialchars($server_info['host']).":".htmlspecialchars($server_info['port']).":".htmlspecialchars($server_info['sslmode'])."\">{$lang['strlogout']}</a>";
 				
 				echo "</td>";
 			}
@@ -938,7 +1096,7 @@
 			echo "<div class=\"trail\"><table><tr>";
 			
 			foreach ($trail as $crumb) {
-				echo "<td>";
+				echo "<td class=\"crumb\">";
 				$crumblink = "<a";
 				
 				if (isset($crumb['url']))
@@ -947,7 +1105,17 @@
 				if (isset($crumb['title']))
 					$crumblink .= " title=\"{$crumb['title']}\"";
 				
-				$crumblink .= ">" . htmlspecialchars($crumb['text']) . "</a>";
+				$crumblink .= ">";
+				
+				if (isset($crumb['title']))
+					$iconalt = $crumb['title'];
+				else
+					$iconalt = 'Database Root';
+
+				if (isset($crumb['icon']) && $icon = $this->icon($crumb['icon']))
+					$crumblink .= "<span class=\"icon\"><img src=\"{$icon}\" alt=\"{$iconalt}\" /></span>";
+				 
+				$crumblink .= "<span class=\"label\">" . htmlspecialchars($crumb['text']) . "</span></a>";
 				
 				if (isset($crumb['help']))
 					$this->printHelp($crumblink, $crumb['help']);
@@ -967,7 +1135,7 @@
 		 */
 		function getTrail($subject = null) {
 			global $lang, $conf, $data, $appName;
-			
+
 			$trail = array();
 			$vars = '';
 			$done = false;
@@ -975,6 +1143,7 @@
 			$trail['root'] = array(
 				'text'  => $appName,
 				'url'   => 'redirect.php?subject=root',
+				'icon'  => 'Introduction'
 			);
 			
 			if ($subject == 'root') $done = true;
@@ -986,7 +1155,8 @@
 					'title' => $lang['strserver'],
 					'text'  => $server_info['desc'],
 					'url'   => "redirect.php?subject=server&{$vars}",
-					'help'  => 'pg.server'
+					'help'  => 'pg.server',
+					'icon'  => 'Server'
 				);
 			}
 			if ($subject == 'server') $done = true;
@@ -997,10 +1167,20 @@
 					'title' => $lang['strdatabase'],
 					'text'  => $_REQUEST['database'],
 					'url'   => "redirect.php?subject=database&{$vars}",
-					'help'  => 'pg.database'
+					'help'  => 'pg.database',
+					'icon'  => 'Database'
+				);
+			} elseif (isset($_REQUEST['rolename']) && !$done) {
+				$vars .= "subject=role&action=properties&rolename=".urlencode($_REQUEST['rolename']);
+				$trail['role'] = array(
+					'title' => $lang['strrole'],
+					'text'  => $_REQUEST['rolename'],
+					'url'   => "redirect.php?{$vars}",
+					'help'  => 'pg.role',
+					'icon'  => 'Roles'
 				);
 			}
-			if ($subject == 'database') $done = true;
+			if ($subject == 'database' || $subject == 'role') $done = true;
 			
 			if (isset($_REQUEST['schema']) && !$done) {
 				$vars .= 'schema='.urlencode($_REQUEST['schema']).'&';
@@ -1008,7 +1188,8 @@
 					'title' => $lang['strschema'],
 					'text'  => $_REQUEST['schema'],
 					'url'   => "redirect.php?subject=schema&{$vars}",
-					'help'  => 'pg.schema'
+					'help'  => 'pg.schema',
+					'icon'  => 'Schema'
 				);
 			}
 			if ($subject == 'schema') $done = true;
@@ -1019,7 +1200,8 @@
 					'title' => 'Slony Cluster',
 					'text'  => $_REQUEST['slony_cluster'],
 					'url'   => "redirect.php?subject=slony_cluster&{$vars}",
-					'help'  => 'sl.cluster'
+					'help'  => 'sl.cluster',
+					'icon'  => 'Cluster'
 				);
 			}
 			if ($subject == 'slony_cluster') $done = true;
@@ -1030,7 +1212,8 @@
 					'title' => $lang['strtable'],
 					'text'  => $_REQUEST['table'],
 					'url'   => "redirect.php?{$vars}",
-					'help'  => 'pg.table'
+					'help'  => 'pg.table',
+					'icon'  => 'Table'
 				);
 			} elseif (isset($_REQUEST['view']) && !$done) {
 				$vars .= "subject=view&view=".urlencode($_REQUEST['view']);
@@ -1038,7 +1221,8 @@
 					'title' => $lang['strview'],
 					'text'  => $_REQUEST['view'],
 					'url'   => "redirect.php?{$vars}",
-					'help'  => 'pg.view'
+					'help'  => 'pg.view',
+					'icon'  => 'View'
 				);
 			}
 			if ($subject == 'table' || $subject == 'view') $done = true;
@@ -1052,7 +1236,19 @@
 							'title' => $lang['str'.$subject],
 							'text'  => $_REQUEST[$subject],
 							'url'   => "redirect.php?{$vars}",
-							'help'  => 'pg.function'
+							'help'  => 'pg.function',
+							'icon'  => 'Function'
+						);
+						break;
+					case 'aggregate':
+						$vars .= "subject=aggregate&action=properties&aggrname=".urlencode($_REQUEST['aggrname']);
+						$vars .= "&aggrtype=".urlencode($_REQUEST['aggrtype']);	
+						$trail[$subject] = array(
+							'title' => $lang['straggregate'],
+							'text'  => $_REQUEST['aggrname'],
+							'url'   => "redirect.php?{$vars}",
+							'help'  => 'pg.aggregate',
+							'icon'  => 'Aggregate'
 						);
 						break;
 					case 'slony_node':
@@ -1061,7 +1257,8 @@
 							'title' => 'Slony Node',
 							'text'  => $_REQUEST['no_name'],
 							'url'   => "redirect.php?{$vars}",
-							'help'  => 'sl.'.$subject
+							'help'  => 'sl.'.$subject,
+							'icon'  => 'Node'
 						);
 						break;
 					case 'slony_set':
@@ -1071,15 +1268,33 @@
 							'title' => $lang['str'.$subject],
 							'text'  => $_REQUEST[$subject],
 							'url'   => "redirect.php?{$vars}",
-							'help'  => 'sl.'.$subject
+							'help'  => 'sl.'.$subject,
+							'icon'  => 'AvailableReplicationSet'
+						);
+						break;
+					case 'column':
+						$vars .= "&column={$_REQUEST['column']}&subject=column";
+						$trail['column'] = array (
+							'title' => $lang['strcolumn'],
+							'text'  => $_REQUEST['column'],
+							'icon'	=> 'Column',
+							'url'   => "redirect.php?{$vars}"
 						);
 						break;
 					default:
 						if (isset($_REQUEST[$subject])) {
-							$trail[$_REQUEST[$subject]] = array(
+							switch ($subject) {
+								case 'domain': $icon = 'Domain'; break;
+								case 'sequence': $icon = 'Sequence'; break;
+								case 'type': $icon = 'Type'; break;
+								case 'operator': $icon = 'Operator'; break;
+								default: $icon = null; break;
+							}
+							$trail[$subject] = array(
 								'title' => $lang['str'.$subject],
 								'text'  => $_REQUEST[$subject],
-								'help'  => 'pg.'.$subject	
+								'help'  => 'pg.'.$subject,
+								'icon'  => $icon,
 							);
 						}
 				}
@@ -1350,7 +1565,7 @@
 				foreach ($columns as $column_id => $column) {
 					switch ($column_id) {
 						case 'actions':
-							echo "<th class=\"data\" colspan=\"", count($actions), "\">{$column['title']}</th>\n";
+							if (sizeof($actions) > 0) echo "<th class=\"data\" colspan=\"", count($actions), "\">{$column['title']}</th>\n";
 							break;
 						default:
 							echo "<th class=\"data\">";
@@ -1438,6 +1653,7 @@
 		 *        'openIcon' - an alternative icon when the node is expanded
 		 *        'toolTip' - tool tip text for the node
 		 *        'action' - URL to visit when single clicking the node
+		 *        'iconAction' - URL to visit when single clicking the icon node
 		 *        'branch' - URL for child nodes (tree XML)
 		 *        'expand' - the action to return XML for the subtree
 		 *        'nodata' - message to display when node has no children
@@ -1467,13 +1683,14 @@
 					
 					$icon = $this->icon(value($attrs['icon'], $rec));
 					echo value_xml_attr('icon', $icon, $rec);
+					echo value_xml_attr('iconaction', $attrs['iconAction'], $rec);
 					
-					if (!empty($attrs['openIcon'])) {
+					if (!empty($attrs['openicon'])) {
 						$icon = $this->icon(value($attrs['openIcon'], $rec));
 					}
-					echo value_xml_attr('openIcon', $icon, $rec);
+					echo value_xml_attr('openicon', $icon, $rec);
 					
-					echo value_xml_attr('toolTip', $attrs['toolTip'], $rec);
+					echo value_xml_attr('tooltip', $attrs['toolTip'], $rec);
 					
 					echo "/>\n";
 					
@@ -1481,7 +1698,7 @@
 				}
 			} else {
 				$msg = isset($attrs['nodata']) ? $attrs['nodata'] : $lang['strnoobjects'];
-				echo "<tree text=\"{$msg}\" onaction=\"this.parentNode.reload()\" icon=\"", $this->icon('error'), "\"/>\n";
+				echo "<tree text=\"{$msg}\" onaction=\"this.parentNode.reload()\" icon=\"", $this->icon('ObjectNotFound'), "\"/>\n";
 			}
 			
 			if (!isset($attrs['nofoot']) || $attrs['nofoot'] === false) {
@@ -1561,7 +1778,7 @@
 			$srvs = isset($_SESSION['webdbLogin']) && is_array($_SESSION['webdbLogin']) ? $_SESSION['webdbLogin'] : array();
 
 			foreach($conf['servers'] as $idx => $info) {
-				$server_id = $info['host'].':'.$info['port'];
+				$server_id = $info['host'].':'.$info['port'].':'.$info['sslmode'];
 				
 				if (!isset($srvs[$server_id])) {
 					$srvs[$server_id] = $info;
@@ -1600,7 +1817,7 @@
 			
 			// Otherwise, look for it in the conf file
 			foreach($conf['servers'] as $idx => $info) {
-				if ($server_id == $info['host'].':'.$info['port']) {
+				if ($server_id == $info['host'].':'.$info['port'].':'.$info['sslmode']) {
 					// Automatically use shared credentials if available
 					if (!isset($info['username']) && isset($_SESSION['sharedUsername'])) {
 						$info['username'] = $_SESSION['sharedUsername'];
