@@ -3,7 +3,7 @@
 	/**
 	 * Manage schemas within a database
 	 *
-	 * $Id: database.php,v 1.78 2005/11/09 09:05:58 jollytoad Exp $
+	 * $Id: database.php,v 1.88.2.2 2007/05/28 17:21:56 ioguix Exp $
 	 */
 
 	// Include application functions
@@ -11,7 +11,6 @@
 
 	$action = (isset($_REQUEST['action'])) ? $_REQUEST['action'] : '';
 	if (!isset($msg)) $msg = '';
-	$PHP_SELF = $_SERVER['PHP_SELF'];
 
 	function _highlight($string, $term) {
 		return str_replace($term, "<b>{$term}</b>", $string);
@@ -287,34 +286,34 @@
 		echo "<tr><th class=\"data\">{$lang['strformat']}</th><th class=\"data\" colspan=\"2\">{$lang['stroptions']}</th></tr>\n";
 		// Data only
 		echo "<tr><th class=\"data left\" rowspan=\"2\">";
-		echo "<input type=\"radio\" name=\"what\" value=\"dataonly\" checked=\"checked\" />{$lang['strdataonly']}</th>\n";
+		echo "<input type=\"radio\" id=\"what1\" name=\"what\" value=\"dataonly\" checked=\"checked\" /><label for=\"what1\">{$lang['strdataonly']}</label></th>\n";
 		echo "<td>{$lang['strformat']}</td>\n";
 		echo "<td><select name=\"d_format\">\n";
 		echo "<option value=\"copy\">COPY</option>\n";
 		echo "<option value=\"sql\">SQL</option>\n";
 		echo "</select>\n</td>\n</tr>\n";
-		echo "<td>{$lang['stroids']}</td><td><input type=\"checkbox\" name=\"d_oids\" /></td>\n</tr>\n";
+		echo "<tr><td><label for=\"d_oids\">{$lang['stroids']}</label></td><td><input type=\"checkbox\" id=\"d_oids\" name=\"d_oids\" /></td>\n</tr>\n";
 		// Structure only
-		echo "<tr><th class=\"data left\"><input type=\"radio\" name=\"what\" value=\"structureonly\" />{$lang['strstructureonly']}</th>\n";
-		echo "<td>{$lang['strdrop']}</td><td><input type=\"checkbox\" name=\"s_clean\" /></td>\n</tr>\n";
+		echo "<tr><th class=\"data left\"><input type=\"radio\" id=\"what2\" name=\"what\" value=\"structureonly\" /><label for=\"what2\">{$lang['strstructureonly']}</label></th>\n";
+		echo "<td><label for=\"s_clean\">{$lang['strdrop']}</label></td><td><input type=\"checkbox\" id=\"s_clean\" name=\"s_clean\" /></td>\n</tr>\n";
 		// Structure and data
 		echo "<tr><th class=\"data left\" rowspan=\"3\">";
-		echo "<input type=\"radio\" name=\"what\" value=\"structureanddata\" />{$lang['strstructureanddata']}</th>\n";
+		echo "<input type=\"radio\" id=\"what3\" name=\"what\" value=\"structureanddata\" /><label for=\"what3\">{$lang['strstructureanddata']}</label></th>\n";
 		echo "<td>{$lang['strformat']}</td>\n";
 		echo "<td><select name=\"sd_format\">\n";
 		echo "<option value=\"copy\">COPY</option>\n";
 		echo "<option value=\"sql\">SQL</option>\n";
 		echo "</select>\n</td>\n</tr>\n";
-		echo "<td>{$lang['strdrop']}</td><td><input type=\"checkbox\" name=\"sd_clean\" /></td>\n</tr>\n";
-		echo "<td>{$lang['stroids']}</td><td><input type=\"checkbox\" name=\"sd_oids\" /></td>\n</tr>\n";
+		echo "<tr><td><label for=\"sd_clean\">{$lang['strdrop']}</label></td><td><input type=\"checkbox\" id=\"sd_clean\" name=\"sd_clean\" /></td>\n</tr>\n";
+		echo "<tr><td><label for=\"sd_oids\">{$lang['stroids']}</label></td><td><input type=\"checkbox\" id=\"sd_oids\" name=\"sd_oids\" /></td>\n</tr>\n";
 		echo "</table>\n";
 		
 		echo "<h3>{$lang['stroptions']}</h3>\n";
-		echo "<p><input type=\"radio\" name=\"output\" value=\"show\" checked=\"checked\" />{$lang['strshow']}\n";
-		echo "<br/><input type=\"radio\" name=\"output\" value=\"download\" />{$lang['strdownload']}\n";
+		echo "<p><input type=\"radio\" id=\"output1\" name=\"output\" value=\"show\" checked=\"checked\" /><label for=\"output1\">{$lang['strshow']}</label>\n";
+		echo "<br/><input type=\"radio\" id=\"output2\" name=\"output\" value=\"download\" /><label for=\"output2\">{$lang['strdownload']}</label>\n";
 		// MSIE cannot download gzip in SSL mode - it's just broken
 		if (!(strstr($_SERVER['HTTP_USER_AGENT'], 'MSIE') && isset($_SERVER['HTTPS']))) {
-			echo "<br /><input type=\"radio\" name=\"output\" value=\"gzipped\" />{$lang['strdownloadgzipped']}\n";
+			echo "<br /><input type=\"radio\" id=\"output3\" name=\"output\" value=\"gzipped\" /><label for=\"output3\">{$lang['strdownloadgzipped']}</label>\n";
 		}
 		echo "</p>\n";
 		echo "<p><input type=\"hidden\" name=\"action\" value=\"export\" />\n";
@@ -332,8 +331,7 @@
 		global $lang;
 
 		// Fetch the variables from the database
-		$variables = $data->getVariables();
-		
+		$variables = $data->getVariables();	
 		$misc->printTrail('database');
 		$misc->printTabs('database','variables');
 
@@ -361,13 +359,43 @@
 		global $PHP_SELF, $data, $misc;
 		global $lang;
 
-		// Fetch the processes from the database
-		$processes = $data->getProcesses($_REQUEST['database']);
-		
 		$misc->printTrail('database');
 		$misc->printTabs('database','processes');
 		$misc->printMsg($msg);
+
+		// Display prepared transactions
+		if($data->hasPreparedXacts()) {
+			echo "<h3>{$lang['strpreparedxacts']}</h3>\n";
+			$prep_xacts = $data->getPreparedXacts($_REQUEST['database']);
 		
+			$columns = array(
+				'transaction' => array(
+					'title' => $lang['strxactid'],
+					'field' => 'transaction',
+				),
+				'gid' => array(
+					'title' => $lang['strgid'],
+					'field' => 'gid',
+				),
+				'prepared' => array(
+					'title' => $lang['strstarttime'],
+					'field' => 'prepared',
+				),
+				'owner' => array(
+					'title' => $lang['strowner'],
+					'field' => 'owner',
+				),
+			);
+
+			$actions = array();
+
+			$misc->printTable($prep_xacts, $columns, $actions, $lang['strnodata']);
+		}
+
+		// Fetch the processes from the database
+		echo "<br /><h3>{$lang['strprocesses']}</h3>\n";
+		$processes = $data->getProcesses($_REQUEST['database']);
+				
 		$columns = array(
 			'user' => array(
 				'title' => $lang['strusername'],
@@ -402,10 +430,56 @@
 		
 		// Remove query start time for <7.4
 		if (!isset($processes->f['query_start'])) unset($columns['start_time']);
-		
+
 		$misc->printTable($processes, $columns, $actions, $lang['strnodata']);
 	}
 
+	/**
+	 * Show the existing table locks in the current database
+	*/
+	function doLocks() {
+		global $PHP_SELF, $data, $misc;
+		global $lang;
+
+		// Get the info from the pg_locks view
+		$variables = $data->getLocks();
+
+		$misc->printTrail('database');
+		$misc->printTabs('database','locks');
+
+		$columns = array(
+			'namespace' => array(
+				'title' => $lang['strschema'],
+				'field' => 'nspname',
+			),
+			'tablename' => array(
+				'title' => $lang['strtablename'],
+				'field' => 'tablename',
+			),
+			'transactionid' => array(
+				'title' => $lang['strtransaction'],
+				'field' => 'transaction',
+			),
+			'processid' => array(
+				'title' => $lang['strprocessid'],
+				'field' => 'pid',
+			),
+			'mode' => array(
+				'title' => $lang['strmode'],
+				'field' => 'mode',
+			),
+			'granted' => array(
+				'title' => $lang['strislockheld'],
+				'field' => 'granted',
+				'type'  => 'yesno',
+			),
+		);
+
+		$actions = array();
+
+		$misc->printTable($variables, $columns, $actions, $lang['strnodata']);
+	}
+
 	/**
 	 * Allow database administration and tuning tasks
 	 */
@@ -438,57 +512,279 @@
 				$misc->printTabs('database','admin');
 				$misc->printMsg($msg);
 				
+				echo "<table width=\"60%\">\n";
+				echo "<tr>\n";
+				echo "<th class=\"data\">";
+				$misc->printHelp($lang['strvacuum'],'pg.admin.vacuum')."</th>\n";
+				echo "</th>";
+				echo "<th class=\"data\">";
+				$misc->printHelp($lang['stranalyze'],'pg.admin.analyze');
+				echo "</th>";
+				if ($data->hasRecluster()){
+					echo "<th class=\"data\">";
+					$misc->printHelp($lang['strclusterindex'],'pg.index.cluster');
+					echo "</th>";
+				}
+				echo "<th class=\"data\">";
+				$misc->printHelp($lang['strreindex'],'pg.index.reindex');
+				echo "</th>";
+				echo "</tr>";	
+
 				// Vacuum
+				echo "<tr>\n";
+				echo "<td class=\"data1\" align=\"center\" valign=\"bottom\">\n";
 				echo "<form name=\"adminfrm\" id=\"adminfrm\" action=\"{$PHP_SELF}\" method=\"post\">\n";
-				echo "<h3>";
-				$misc->printHelp($lang['strvacuum'],'pg.admin.vacuum');
-				echo "</h3>\n";
-				echo "<input type=\"checkbox\" id=\"vacuum_analyze\" name=\"vacuum_analyze\" />{$lang['stranalyze']}<br />\n";
+				echo "<input type=\"checkbox\" id=\"vacuum_analyze\" name=\"vacuum_analyze\" /><label for=\"vacuum_analyze\">{$lang['stranalyze']}</label><br />\n";
 				if ($data->hasFullVacuum()) {
-					echo "<input type=\"checkbox\" id=\"vacuum_full\" name=\"vacuum_full\" />{$lang['strfull']}<br />\n";				
-					echo "<input type=\"checkbox\" id=\"vacuum_freeze\" name=\"vacuum_freeze\" />{$lang['strfreeze']}<br />\n";
+					echo "<input type=\"checkbox\" id=\"vacuum_full\" name=\"vacuum_full\" /><label for=\"vacuum_full\">{$lang['strfull']}</label><br />\n";				
+					echo "<input type=\"checkbox\" id=\"vacuum_freeze\" name=\"vacuum_freeze\" /><label for=\"vacuum_freeze\">{$lang['strfreeze']}</label><br />\n";
 				}
 				echo "<input type=\"submit\" value=\"{$lang['strvacuum']}\" />\n";
 				echo "<input type=\"hidden\" name=\"action\" value=\"vacuum\" />\n";
 				echo $misc->form;
 				echo "</form>\n";								
+				echo "</td>\n";
 
 				// Analyze
+				echo "<td class=\"data1\" align=\"center\" valign=\"bottom\">\n";
 				echo "<form name=\"adminfrm\" id=\"adminfrm\" action=\"{$PHP_SELF}\" method=\"post\">\n";
-				echo "<h3>";
-				$misc->printHelp($lang['stranalyze'],'pg.admin.analyze');
-				echo "</h3>\n";
 				echo "<input type=\"submit\" value=\"{$lang['stranalyze']}\" />\n";
 				echo "<input type=\"hidden\" name=\"action\" value=\"analyze\" />\n";
 				echo $misc->form;
 				echo "</form>\n";
+				echo "</td>\n";
 				
 				// Recluster
 				if ($data->hasRecluster()){
+					echo "<td class=\"data1\" align=\"center\" valign=\"bottom\">\n";
 					echo "<form name=\"adminfrm\" id=\"adminfrm\" action=\"{$PHP_SELF}\" method=\"post\">\n";
-					echo "<h3>";
-					$misc->printHelp($lang['strclusterindex'],'pg.index.cluster');
-					echo "</h3>\n";
 					echo "<input type=\"submit\" value=\"{$lang['strclusterindex']}\" />\n";
 					echo "<input type=\"hidden\" name=\"action\" value=\"recluster\" />\n";
 					echo $misc->form;
 					echo "</form>\n";
+					echo "</td>\n";
 				}
 				
 				// Reindex
+				echo "<td class=\"data1\" align=\"center\" valign=\"bottom\">\n";
 				echo "<form name=\"adminfrm\" id=\"adminfrm\" action=\"{$PHP_SELF}\" method=\"post\">\n";
-				echo "<h3>";
-				$misc->printHelp($lang['strreindex'],'pg.index.reindex');
-				echo "</h3>\n";
-				echo "<input type=\"checkbox\" id=\"reindex_force\" name=\"reindex_force\" />{$lang['strforce']}<br />\n";
+				echo "<input type=\"checkbox\" id=\"reindex_force\" name=\"reindex_force\" /><label for=\"reindex_force\">{$lang['strforce']}</label><br />\n";
 				echo "<input type=\"submit\" value=\"{$lang['strreindex']}\" />\n";
 				echo "<input type=\"hidden\" name=\"action\" value=\"reindex\" />\n";
 				echo $misc->form;
 				echo "</form>\n";
+				echo "</td>\n";
+				echo "</tr>\n";
+				echo "</table>\n";
+
+				echo "<br />";
+				echo "<br />";
+
+				if($data->hasAutovacuum()) {
+					$enabled = $data->getVariable('autovacuum');
+					echo "<h3>{$lang['strautovacuum']} ". (($enabled->f['autovacuum'] == 'on') ? $lang['strturnedon'] : $lang['strturnedoff'] ) ."</h3>";
+					// Autovacuum
+					// Fetch the processes from the database
+					$autovac = $data->getAutovacuum();
+		
+					$columns = array(
+						'namespace' => array(
+							'title' => $lang['strschema'],
+							'field' => 'nspname',
+						),	
+						'relname' => array(
+							'title' => $lang['strtable'],
+							'field' => 'relname',
+						),
+						'enabled' => array(
+							'title' => $lang['strenabled'],
+							'field' => 'enabled',
+						),
+						'vac_base_thresh' => array(
+							'title' => $lang['strvacuumbasethreshold'],
+							'field' => 'vac_base_thresh',
+						),
+						'vac_scale_factor' => array(
+							'title' => $lang['strvacuumscalefactor'],
+							'field' => 'vac_scale_factor',
+						),
+						'anl_base_thresh' => array(
+							'title' => $lang['stranalybasethreshold'],
+							'field' => 'anl_base_thresh',
+						),
+						'anl_scale_factor' => array(
+							'title' => $lang['stranalyzescalefactor'],
+							'field' => 'anl_scale_factor',
+						),
+						'vac_cost_delay' => array(
+							'title' => $lang['strvacuumcostdelay'],
+							'field' => 'vac_cost_delay',
+						),
+						'vac_cost_limit' => array(
+							'title' => $lang['strvacuumcostlimit'],
+							'field' => 'vac_cost_limit',
+						),
+					);
+
+					// Maybe we need to check permissions here?
+					$columns['actions'] = array('title' => $lang['stractions']);
+
+					$actions = array(
+						'edit' => array(
+						'title' => $lang['stredit'],
+						'url'   => "{$PHP_SELF}?action=editautovac&amp;schema=pg_catalog&amp;{$misc->href}&amp;",
+						'vars'  => array('key[vacrelid]' => 'vacrelid')
+						),
+						'delete' => array(
+						'title' => $lang['strdelete'],
+						'url'   => "{$PHP_SELF}?action=delautovac&amp;{$misc->href}&amp;",
+						'vars'  => array('key[vacrelid]' => 'vacrelid')
+						)
+					);
+
+					$misc->printTable($autovac, $columns, $actions, $lang['strnodata']);
+				}
+					
 				break;
 		}
 	}
 
+	/**
+	 * Show confirmation of edit and perform actual update of autovacuum entry
+	 */
+	function doEditAutovacuum($confirm, $msg = '') {
+		global $data, $misc, $conf;
+		global $lang;
+		global $PHP_SELF;
+
+		$key = $_REQUEST['key'];
+
+		if ($confirm) {
+			$misc->printTrail('database');
+			$misc->printTabs('database','admin');
+			$misc->printMsg($msg);
+
+			$attrs = $data->getTableAttributes('pg_autovacuum');
+			$rs = $data->browseRow('pg_autovacuum', $key);
+			
+			echo "<form action=\"$PHP_SELF\" method=\"post\" id=\"ac_form\">\n";
+			$elements = 0;
+			$error = true;			
+			if ($rs->recordCount() == 1 && $attrs->recordCount() > 0) {
+				echo "<table>\n";
+
+				// Output table header
+				echo "<tr><th class=\"data\">{$lang['strcolumn']}</th><th class=\"data\">{$lang['strtype']}</th>";
+				echo "<th class=\"data\">{$lang['strformat']}</th>\n";
+				echo "<th class=\"data\">{$lang['strvalue']}</th></tr>";
+
+				$i = 0;
+				$nCC = 0;
+				while (!$attrs->EOF) {
+					$szValueName = "values[{$attrs->f['attname']}]";
+					$szEvents = "";
+					$szDivPH = "";
+					
+					$attrs->f['attnotnull'] = $data->phpBool($attrs->f['attnotnull']);
+					$id = (($i % 2) == 0 ? '1' : '2');
+					
+					// Initialise variables
+					if (!isset($_REQUEST['format'][$attrs->f['attname']]))
+						$_REQUEST['format'][$attrs->f['attname']] = 'VALUE';
+					
+					echo "<tr>\n";
+					echo "<td class=\"data{$id}\" nowrap=\"nowrap\">", $misc->printVal($attrs->f['attname']), "</td>";
+					echo "<td class=\"data{$id}\" nowrap=\"nowrap\">\n";
+					echo $misc->printVal($data->formatType($attrs->f['type'], $attrs->f['atttypmod']));
+					echo "<input type=\"hidden\" name=\"types[", htmlspecialchars($attrs->f['attname']), "]\" value=\"", 
+						htmlspecialchars($attrs->f['type']), "\" /></td>";
+					$elements++;
+					echo "<td class=\"data{$id}\" nowrap=\"nowrap\">\n";
+					echo "<select name=\"format[", htmlspecialchars($attrs->f['attname']), "]\">\n";
+					echo "<option value=\"VALUE\"", ($_REQUEST['format'][$attrs->f['attname']] == 'VALUE') ? ' selected="selected"' : '', ">{$lang['strvalue']}</option>\n";
+					echo "<option value=\"EXPRESSION\"", ($_REQUEST['format'][$attrs->f['attname']] == 'EXPRESSION') ? ' selected="selected"' : '', ">{$lang['strexpression']}</option>\n";
+					echo "</select>\n</td>\n";
+					$elements++;
+
+					echo "<td class=\"data{$id}\" id=\"aciwp{$i}\" nowrap=\"nowrap\">";
+					echo $data->printField($szValueName, $rs->f[$attrs->f['attname']], $attrs->f['type'],array(),$szEvents) . $szDivPH;
+					echo "</td>";
+					$elements++;
+					echo "</tr>\n";
+					$i++;
+					$attrs->moveNext();
+				}
+				echo "</table>\n";
+				$error = false;
+			}
+			elseif ($rs->recordCount() != 1) {
+				echo "<p>{$lang['strrownotunique']}</p>\n";				
+			}
+			else {
+				echo "<p>{$lang['strinvalidparam']}</p>\n";
+			}
+
+			echo "<input type=\"hidden\" name=\"action\" value=\"confeditautovac\" />\n";
+			echo $misc->form;
+			echo "<input type=\"hidden\" name=\"table\" value=\"pg_autovacuum\" />\n";
+			echo "<input type=\"hidden\" name=\"key\" value=\"", htmlspecialchars(serialize($key)), "\" />\n";
+			echo "<p>";
+			if (!$error) echo "<input type=\"submit\" name=\"save\" value=\"{$lang['strsave']}\" />\n";
+			echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" />\n";
+			echo "</p>\n";
+			echo "</form>\n";
+		}
+		else {
+			if (!isset($_POST['values'])) $_POST['values'] = array();
+			if (!isset($_POST['nulls'])) $_POST['nulls'] = array();
+			
+			$status = $data->editRow($_POST['table'], $_POST['values'], $_POST['nulls'], 
+												$_POST['format'], $_POST['types'], unserialize($_POST['key']));
+			if ($status == 0)
+				doAdmin($lang['strrowupdated']);
+			elseif ($status == -2)
+				doEditAutovacuum(true, $lang['strrownotunique']);
+			else
+				doEditAutovacuum(true, $lang['strrowupdatedbad']);
+		}
+
+	}	
+
+
+	/**
+	 * Delete rows from the autovacuum table
+     */
+	function doDelAutovacuum($confirm) {
+		global $PHP_SELF, $data, $misc;
+		global $lang;
+
+		if ($confirm) {
+			$misc->printTrail('database');
+			$misc->printTabs('database','admin');
+			$misc->printTitle($lang['strdeleterow']);
+
+			echo "<p>{$lang['strconfdeleterow']}</p>\n";
+			
+			echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
+			echo "<input type=\"hidden\" name=\"action\" value=\"confdelautovac\" />\n";
+			echo $misc->form;
+			echo "<input type=\"hidden\" name=\"table\" value=\"pg_autovacuum\" />\n";
+			echo "<input type=\"hidden\" name=\"key\" value=\"", htmlspecialchars(serialize($_REQUEST['key'])), "\" />\n";
+			echo "<input type=\"submit\" name=\"yes\" value=\"{$lang['stryes']}\" />\n";
+			echo "<input type=\"submit\" name=\"no\" value=\"{$lang['strno']}\" />\n";
+			echo "</form>\n";
+		}
+		else {
+			$status = $data->deleteRow($_POST['table'], unserialize($_POST['key']));
+			if ($status == 0)
+				doAdmin('',$lang['strrowdeleted']);
+			elseif ($status == -2)
+				doAdmin('',$lang['strrownotunique']);
+			else			
+				doAdmin('',$lang['strrowdeletedbad']);
+		}
+	}
+
 	/**
 	 * Allow execution of arbitrary SQL statements on a database
 	 */
@@ -518,7 +814,7 @@
 		}
 		else echo "</p>\n";
 
-		echo "<input type=\"checkbox\" name=\"paginate\"", (isset($_REQUEST['paginate']) ? ' checked="checked"' : ''), " /> {$lang['strpaginate']}\n";
+		echo "<input type=\"checkbox\" id=\"paginate\" name=\"paginate\"", (isset($_REQUEST['paginate']) ? ' checked="checked"' : ''), " /><label for=\"paginate\">{$lang['strpaginate']}</label>\n";
 		echo "<br />\n";
 		echo "<p><input type=\"submit\" value=\"{$lang['strrun']}\" />\n";
 		if ($data->hasFullExplain()) {
@@ -541,12 +837,15 @@
 		$reqvars = $misc->getRequestVars('database');
 
 		$tabs = $misc->getNavTabs('database');
+		if (!$data->hasSchemas()) {
+			$tabs = array_merge($misc->getNavTabs('schema'), $tabs);
+		}
 
 		$items = $misc->adjustTabsForTree($tabs);
 		
 		$attrs = array(
 			'text'   => noEscape(field('title')),
-			'icon'   => field('icon', 'folder'),
+			'icon'   => field('icon'),
 			'action' => url(field('url'),
 							$reqvars,
 							field('urlvars', array())
@@ -591,12 +890,29 @@
 		case 'processes':
 			doProcesses();
 			break;
+		case 'locks':
+			doLocks();
+			break;
 		case 'export':
 			doExport();
 			break;
 		case 'signal':
 			doSignal();
 			break;
+		case 'editautovac':
+			doEditAutovacuum(true);
+			break;
+		case 'confeditautovac':
+			if (isset($_POST['save'])) doEditAutovacuum(false);
+			else doAdmin();
+			break;
+		case 'delautovac':
+			doDelAutovacuum(true);
+			break;
+		case 'confdelautovac':
+			if (isset($_POST['yes'])) doDelAutovacuum(false);
+			else doAdmin();
+			break;
 		default:
 			doSQL();
 			break;
