@@ -4,7 +4,7 @@
 	 * Japanese language file for phpPgAdmin.
 	 * @maintainer Tadashi Jokagi [elf2000@users.sourceforge.net]
 	 *
-	 * $Id: japanese.php,v 1.16 2005/10/19 08:31:42 chriskl Exp $
+	 * $Id: japanese.php,v 1.16.4.1 2007/01/19 04:27:10 xzilla Exp $
 	 */
 
 	// Language and character set
@@ -15,13 +15,13 @@
 	$lang['applangdir'] = 'ltr';
   
 	// Welcome  
-	$lang['strintro'] = '褦phpPgAdminء';
+	$lang['strintro'] = '褦 phpPgAdmin ء';
 	$lang['strppahome'] = 'phpPgAdmin ۡڡ';
 	$lang['strpgsqlhome'] = 'PostgreSQL ۡڡ';
 	$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
 	$lang['strlocaldocs'] = 'PostgreSQL ɥ ()';
 	$lang['strreportbug'] = 'Хݡ';
-	$lang['strviewfaq'] = 'FAQ򸫤';
+	$lang['strviewfaq'] = 'FAQ 򸫤';
 	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/?page=faq';
 	
 	// Basic strings
@@ -89,7 +89,6 @@
 	$lang['strallowednulls']  =  'NULL ʸĤ';
 	$lang['strbackslashn']  =  '\N';
 	$lang['strnull']  =  'Null';
-	$lang['strnull']  =  'NULL (The word)';
 	$lang['stremptystring']  =  'ʸ/';
 	$lang['strsql'] = 'SQL';
 	$lang['stradmin'] = '';
@@ -122,19 +121,27 @@ $lang['strclustered'] = 'Clustered?';
 	$lang['strdownloadgzipped'] = 'gzip ǰ̤ƥ';
 	$lang['strinfo'] = '';
 	$lang['stroids'] = 'OID ';
-	$lang['stradvanced'] = '٤ʰ';
+	$lang['stradvanced'] = '٤';
 	$lang['strvariables'] = 'ѿ';
 	$lang['strprocess'] = 'ץ';
 	$lang['strprocesses'] = 'ץ';
 	$lang['strsetting'] = '';
 	$lang['streditsql'] = 'SQL Խ';
-	$lang['strruntime'] = '¹Ի: %s ms';
+	$lang['strruntime'] = '¹Ի: %s ߥ';
 	$lang['strpaginate'] = 'Paginate results';
 	$lang['struploadscript'] = 'ޤ SQL ץȤ򥢥åץ:';
 	$lang['strstarttime'] = 'ϻ';
 	$lang['strfile'] = 'ե';
 	$lang['strfileimported'] = 'ե򥤥ݡȤޤ';
-$lang['strtrycred']  =  'Use these credentials for all servers';
+	$lang['strtrycred']  =  '٤ƤΥСǤξȤ';
+
+	// Database Sizes
+$lang['strsize']  =  '';
+$lang['strbytes']  =  'Х';
+$lang['strkb']  =  'kB';
+$lang['strmb']  =  'MB';
+$lang['strgb']  =  'GB';
+$lang['strtb']  =  'TB';
 
 	// Error handling
 	$lang['strnoframes'] = 'ΥץꥱѤ뤿ˤϥե졼बѲǽʥ֥饦ɬפǤ';
@@ -192,7 +199,7 @@ $lang['strtrycred']  =  'Use these credentials for all servers';
 	$lang['strinsertandrepeat'] = 'ȷ֤';
 	$lang['strnumcols'] = 'ο';
 	$lang['strcolneedsname'] = '̾ꤷʤФޤ';
-	$lang['strselectallfields'] = 'ƤΥեɤ';
+	$lang['strselectallfields'] = '٤ƤΥեɤ򤹤';
 	$lang['strselectneedscol'] = 'ʤȤ쥫ɬפǤ';
 	$lang['strselectunary'] = 'ñΥڥ졼ͤĤȤǤޤ';
 	$lang['straltercolumn'] = 'ѹ';
@@ -201,7 +208,7 @@ $lang['strtrycred']  =  'Use these credentials for all servers';
 	$lang['strconfdropcolumn'] = '˥%sפơ֥%sפ˴ƤǤ?';
 	$lang['strcolumndropped'] = '˴ޤ';
 	$lang['strcolumndroppedbad'] = '˴˼Ԥޤ';
-	$lang['straddcolumn'] = 'ɲä';
+	$lang['straddcolumn'] = 'ɲ';
 	$lang['strcolumnadded'] = 'ɲäޤ';
 	$lang['strcolumnaddedbad'] = 'ɲä˼Ԥޤ';
 	$lang['strcascade'] = '';
@@ -210,9 +217,9 @@ $lang['strtrycred']  =  'Use these credentials for all servers';
 	$lang['strdataonly'] = 'ǡΤ';
 	$lang['strstructureonly'] = '¤Τ';
 	$lang['strstructureanddata'] = '¤ȥǡ';
-$lang['strtabbed'] = 'Tabbed';
+	$lang['strtabbed'] = 'ֶڤ';
 	$lang['strauto'] = 'ư';
-	$lang['strconfvacuumtable'] = ' "%s"  vacuum ޤ?';
+	$lang['strconfvacuumtable'] = 'ˡ%sפХ塼षޤ?';
 	$lang['strestimatedrowcount'] = 'ɾѥ쥳ɿ';
 
 	// Users
@@ -220,7 +227,7 @@ $lang['strtabbed'] = 'Tabbed';
 	$lang['strusers'] = '桼';
 	$lang['strusername'] = '桼̾';
 	$lang['strpassword'] = 'ѥ';
-	$lang['strsuper'] = 'ѡ桼?';
+	$lang['strsuper'] = 'ѡ桼Ǥ?';
 	$lang['strcreatedb'] = 'ǡ١ޤ?';
 	$lang['strexpires'] = 'ͭ';
 	$lang['strsessiondefaults'] = 'åǥե';
@@ -244,7 +251,7 @@ $lang['strtabbed'] = 'Tabbed';
 		
 	// Groups
 	$lang['strgroup'] = '롼';
-	$lang['strgroups'] = '롼װ';
+	$lang['strgroups'] = '롼';
 	$lang['strnogroup'] = '롼פޤ';
 	$lang['strnogroups'] = '롼פĤޤ';
 	$lang['strcreategroup'] = '롼פ';
@@ -303,7 +310,7 @@ $lang['strtabbed'] = 'Tabbed';
 	$lang['strforce'] = '';
 	$lang['strsignalsent'] = 'ʥ';
 	$lang['strsignalsentbad'] = 'ʥ˼Ԥޤ';
-	$lang['strallobjects'] = '٤ƤΥ֥Ȱ';
+	$lang['strallobjects'] = '٤ƤΥ֥';
 	$lang['strdatabasealtered']  =  'ǡ١ѹޤ';
 	$lang['strdatabasealteredbad']  =  'ǡ١ѹ˼Ԥޤ';
 
@@ -331,7 +338,7 @@ $lang['strviewlink'] = 'Linking Keys';
 
 	// Sequences
 	$lang['strsequence'] = '';
-	$lang['strsequences'] = '󥹰';
+	$lang['strsequences'] = '';
 	$lang['strshowallsequences'] = '󥹤򸫤';
 	$lang['strnosequence'] = '󥹤ޤ';
 	$lang['strnosequences'] = '󥹤Ĥޤ';
@@ -343,7 +350,7 @@ $lang['strviewlink'] = 'Linking Keys';
 	$lang['strminvalue'] = 'Ǿ';
 	$lang['strcachevalue'] = 'å';
 	$lang['strlogcount'] = '';
-$lang['striscycled'] = 'Is Cycled?';
+	$lang['striscycled'] = 'Cycle ޤ?';
 $lang['striscalled'] = 'Is Called?';
 	$lang['strsequenceneedsname'] = '̾ꤷʤФʤޤ';
 	$lang['strsequencecreated'] = '󥹤ޤ';
@@ -499,14 +506,14 @@ $lang['strpassbyval'] = 'Passed by val?';
 	$lang['strconfdroptype'] = '˥ǡ%sפ˴ޤ?';
 	$lang['strtypedropped'] = 'ǡ˴ޤ';
 	$lang['strtypedroppedbad'] = 'ǡ˴˼Ԥޤ';
-$lang['strflavor'] = 'Flavor';
+	$lang['strflavor'] = '';
 	$lang['strbasetype'] = '';
 	$lang['strcompositetype'] = 'ʣ緿';
-$lang['strpseudotype'] = 'Pseudo';
+	$lang['strpseudotype'] = 'ǡ';
 
 	// Schemas
 	$lang['strschema'] = '';
-	$lang['strschemas'] = 'ް';
+	$lang['strschemas'] = '';
 	$lang['strshowallschemas'] = 'ޤɽ';
 	$lang['strnoschema'] = 'ޤޤ';
 	$lang['strnoschemas'] = 'ޤĤޤ';
@@ -524,7 +531,7 @@ $lang['strpseudotype'] = 'Pseudo';
 
 	// Reports
 	$lang['strreport'] = 'ݡ';
-	$lang['strreports'] = 'ݡȰ';
+	$lang['strreports'] = 'ݡ';
 	$lang['strshowallreports'] = 'ݡȤ򸫤';
 	$lang['strnoreports'] = 'ݡȤĤޤ';
 	$lang['strcreatereport'] = 'ݡȤ';
@@ -553,7 +560,7 @@ $lang['strpseudotype'] = 'Pseudo';
 
 	// Operators
 	$lang['stroperator'] = '黻';
-	$lang['stroperators'] = '黻Ұ';
+	$lang['stroperators'] = '黻';
 	$lang['strshowalloperators'] = '黻Ҥ򸫤';
 	$lang['strnooperator'] = '黻ҤĤޤ';
 	$lang['strnooperators'] = '黻ҥ饹Ĥޤ';
@@ -578,7 +585,7 @@ $lang['strpseudotype'] = 'Pseudo';
 	$lang['stroperatordroppedbad'] = '黻Ҥ˴˼Ԥޤ';
 
 	// Casts
-	$lang['strcasts'] = '㥹Ȱ';
+	$lang['strcasts'] = '㥹';
 	$lang['strnocasts'] = '㥹ȤĤޤ';
 	$lang['strsourcetype'] = '';
 	$lang['strtargettype'] = 'åȥ';
@@ -604,7 +611,7 @@ $lang['strtrusted'] = 'Trusted';
 	$lang['strchildtables'] = 'ҥơ֥';
 
 	// Aggregates
-	$lang['straggregates'] = 'װ';
+	$lang['straggregates'] = '';
 	$lang['strnoaggregates'] = 'פޤ';
 	$lang['stralltypes'] = '(ƤΥ)';
 
@@ -691,14 +698,14 @@ $lang['strtrusted'] = 'Trusted';
 	$lang['strpathdroppedbad']  =  'ѥ˴˼Ԥޤ';
 
 	// Slony listens
-$lang['strlistens']  =  'Listens';
-$lang['strnolistens']  =  'No listens found.';
-$lang['strcreatelisten']  =  'Create listen';
-$lang['strlistencreated']  =  'Listen created.';
-$lang['strlistencreatedbad']  =  'Listen creation failed.';
-$lang['strconfdroplisten']  =  'Are you sure you want to drop listen "%s"?';
-$lang['strlistendropped']  =  'Listen dropped.';
-$lang['strlistendroppedbad']  =  'Listen drop failed.';
+	$lang['strlistens']  =  'å';
+	$lang['strnolistens']  =  'å󤬸Ĥޤ';
+	$lang['strcreatelisten']  =  'å';
+	$lang['strlistencreated']  =  'åޤ';
+	$lang['strlistencreatedbad']  =  'åκ˼Ԥޤ';
+	$lang['strconfdroplisten']  =  '˥å%sפ˴ޤ?';
+	$lang['strlistendropped']  =  'å˴ޤ';
+	$lang['strlistendroppedbad']  =  'å˴˼Ԥޤ';
 
 	// Slony replication sets
 	$lang['strrepsets']  =  'ץꥱ󥻥å';
@@ -753,11 +760,11 @@ $lang['strlistendroppedbad']  =  'Listen drop failed.';
 	$lang['strsequenceremovedfromrepsetbad']  =  'ץꥱ󥻥åȤ饷󥹤κ˼Ԥޤ';
 
 	// Slony subscriptions
-$lang['strsubscriptions']  =  'Subscriptions';
-$lang['strnosubscriptions']  =  'No subscriptions found.';
+	$lang['strsubscriptions']  =  '֥ץ';
+	$lang['strnosubscriptions']  =  '֥ץ󤬸Ĥޤ';
 
 	// Miscellaneous
-	$lang['strtopbar'] = '%s  %s ݡֹ %s ³ -- 桼%sפǥۥȡ%sפ˥';
+	$lang['strtopbar'] = 'С %2$s Υݡֹ %3$s Ǽ¹ %1$s ³ -- 桼%4$sפȤƥ(%5$s)';
 	$lang['strtimefmt'] = 'Y ǯ n  j  G:i';
 	$lang['strhelp'] = 'إ';
 	$lang['strhelpicon'] = '?';
