@@ -4,7 +4,7 @@
 	 * English language file for phpPgAdmin.  Use this as a basis
 	 * for new translations.
 	 *
-	 * $Id: english.php,v 1.135.2.1 2005/11/19 09:51:27 chriskl Exp $
+	 * $Id: english.php,v 1.151.2.2 2007/01/21 21:25:24 xzilla Exp $
 	 */
 
 	// Language and character set
@@ -41,6 +41,8 @@
 	$lang['strdefinition'] = 'Definition';
 	$lang['strproperties'] = 'Properties';
 	$lang['strbrowse'] = 'Browse';
+	$lang['strenable'] = 'Enable';
+	$lang['strdisable'] = 'Disable';
 	$lang['strdrop'] = 'Drop';
 	$lang['strdropped'] = 'Dropped';
 	$lang['strnull'] = 'Null';
@@ -58,6 +60,7 @@
 	$lang['stralter'] = 'Alter';
 	$lang['strok'] = 'OK';
 	$lang['strcancel'] = 'Cancel';
+	$lang['strac'] = 'Enable AutoComplete';
 	$lang['strsave'] = 'Save';
 	$lang['strreset'] = 'Reset';
 	$lang['strinsert'] = 'Insert';
@@ -86,7 +89,7 @@
 	$lang['strprimary'] = 'Primary';
 	$lang['strexport'] = 'Export';
 	$lang['strimport'] = 'Import';
-	$lang['strallowednulls'] = 'Allowed NULL Characters';
+	$lang['strallowednulls'] = 'Allowed NULL characters';
 	$lang['strbackslashn'] = '\N';
 	$lang['strnull'] = 'NULL (The word)';
 	$lang['stremptystring'] = 'Empty string/field';
@@ -135,6 +138,14 @@
 	$lang['strfileimported'] = 'File imported.';
 	$lang['strtrycred'] = 'Use these credentials for all servers';
 
+	// Database Sizes
+	$lang['strsize'] = 'Size';
+	$lang['strbytes'] = 'bytes';
+	$lang['strkb'] = 'kB';
+	$lang['strmb'] = 'MB';
+	$lang['strgb'] = 'GB';
+	$lang['strtb'] = 'TB';
+
 	// Error handling
 	$lang['strnoframes'] = 'This application works best with a frames-enabled browser, but can be used without frames by following the link below.';
 	$lang['strnoframeslink'] = 'Use without frames';
@@ -214,6 +225,9 @@
 	$lang['strconfvacuumtable'] = 'Are you sure you want to vacuum &quot;%s&quot;?';
 	$lang['strestimatedrowcount'] = 'Estimated row count';
 
+	// Columns
+	$lang['strcolprop'] = 'Column Properties';
+		
 	// Users
 	$lang['struser'] = 'User';
 	$lang['strusers'] = 'Users';
@@ -255,6 +269,8 @@
 	$lang['strgroupdropped'] = 'Group dropped.';
 	$lang['strgroupdroppedbad'] = 'Group drop failed.';
 	$lang['strmembers'] = 'Members';
+	$lang['strmemberof'] = 'Member of';
+	$lang['stradminmembers'] = 'Admin members';
 	$lang['straddmember'] = 'Add member';
 	$lang['strmemberadded'] = 'Member added.';
 	$lang['strmemberaddedbad'] = 'Member add failed.';
@@ -262,6 +278,32 @@
 	$lang['strconfdropmember'] = 'Are you sure you want to drop the member &quot;%s&quot; from the group &quot;%s&quot;?';
 	$lang['strmemberdropped'] = 'Member dropped.';
 	$lang['strmemberdroppedbad'] = 'Member drop failed.';
+	
+	// Roles
+	$lang['strrole'] = 'Role';
+	$lang['strroles'] = 'Roles';
+	$lang['strrolename'] = 'Rolename';
+	$lang['strshowallroles'] = 'Show all roles';
+	$lang['strinheritsprivs'] = 'Inherits privileges?';
+	$lang['strcreaterole'] = 'Create role';
+	$lang['strcancreaterole'] = 'Create role?';
+	$lang['strrolecreated'] = 'Role created.';
+	$lang['strrolecreatedbad'] = 'Create role failed.';
+	$lang['stralterrole'] = 'Alter role';
+	$lang['strroleupdated'] = 'Role updated.';
+	$lang['strroleupdatedbad'] = 'Role update failed.';
+	$lang['strcatupdate'] = 'Modify catalogs?';
+	$lang['strcanlogin'] = 'Can login?';
+	$lang['strconnlimit'] = 'Connection limit';
+	$lang['strdroprole'] = 'Drop role';
+	$lang['strmaxconnections'] = 'Max connections';
+	$lang['strconfdroprole'] = 'Are you sure you want to drop the role &quot;%s&quot;?';
+	$lang['strroledropped'] = 'Role dropped.';
+	$lang['strroledroppedbad'] = 'Role drop failed.';
+	$lang['strnoroles'] = 'No roles found.';
+	$lang['strnolimit'] = 'No limit';
+	$lang['strnever'] = 'Never';
+	$lang['strroleneedsname'] = 'You must give a name for the role.';
 
 	// Privileges
 	$lang['strprivilege'] = 'Privilege';
@@ -352,11 +394,20 @@
 	$lang['strsequencedroppedbad'] = 'Sequence drop failed.';
 	$lang['strsequencereset'] = 'Sequence reset.';
 	$lang['strsequenceresetbad'] = 'Sequence reset failed.'; 
+ 	$lang['straltersequence'] = 'Alter sequence';
+ 	$lang['strsequencealtered'] = 'Sequence altered.';
+ 	$lang['strsequencealteredbad'] = 'Sequence alteration failed.';
+ 	$lang['strsetval'] = 'Set value';
+ 	$lang['strsequencesetval'] = 'Sequence value set.';
+ 	$lang['strsequencesetvalbad'] = 'Sequence value set failed.';
+ 	$lang['strnextval'] = 'Increment value';
+ 	$lang['strsequencenextval'] = 'Sequence incremented.';
+ 	$lang['strsequencenextvalbad'] = 'Sequence increment failed.';
 
 	// Indexes
 	$lang['strindex'] = 'Index';
 	$lang['strindexes'] = 'Indexes';
-	$lang['strindexname'] = 'Index Name';
+	$lang['strindexname'] = 'Index name';
 	$lang['strshowallindexes'] = 'Show all indexes';
 	$lang['strnoindex'] = 'No index found.';
 	$lang['strnoindexes'] = 'No indexes found.';
@@ -439,7 +490,6 @@
 	$lang['strcreatecfunction'] = 'Create C function';
 	$lang['strfunctionname'] = 'Function name';
 	$lang['strreturns'] = 'Returns';
-	$lang['strarguments'] = 'Arguments';
 	$lang['strproglanguage'] = 'Programming language';
 	$lang['strfunctionneedsname'] = 'You must give a name for your function.';
 	$lang['strfunctionneedsdef'] = 'You must give a definition for your function.';
@@ -452,6 +502,20 @@
 	$lang['strfunctionupdatedbad'] = 'Function update failed.';
 	$lang['strobjectfile'] = 'Object File';
 	$lang['strlinksymbol'] = 'Link Symbol';
+	$lang['strarguments'] = 'Arguments';
+	$lang['strargname'] = 'Name';
+	$lang['strargmode'] = 'Mode';
+	$lang['strargtype'] = 'Type';
+	$lang['strargadd'] = 'Add another argument';
+	$lang['strargremove'] = 'Remove this argument';
+	$lang['strargnoargs'] = 'This function will not take any arguments.';
+	$lang['strargenableargs'] = 'Enable arguments being passed to this function.';
+	$lang['strargnorowabove'] = 'There needs to be a row above this row.';
+	$lang['strargnorowbelow'] = 'There needs to be a row below this row.';
+	$lang['strargraise'] = 'Move up.';
+	$lang['strarglower'] = 'Move down.';
+	$lang['strargremoveconfirm'] = 'Are you sure you want to remove this argument? This CANNOT be undone.';
+
 
 	// Triggers
 	$lang['strtrigger'] = 'Trigger';
@@ -465,8 +529,14 @@
 	$lang['strtriggercreated'] = 'Trigger created.';
 	$lang['strtriggercreatedbad'] = 'Trigger creation failed.';
 	$lang['strconfdroptrigger'] = 'Are you sure you want to drop the trigger &quot;%s&quot; on &quot;%s&quot;?';
+	$lang['strconfenabletrigger'] = 'Are you sure you want to enable the trigger &quot;%s&quot; on &quot;%s&quot;?';
+	$lang['strconfdisabletrigger'] = 'Are you sure you want to disable the trigger &quot;%s&quot; on &quot;%s&quot;?';
 	$lang['strtriggerdropped'] = 'Trigger dropped.';
 	$lang['strtriggerdroppedbad'] = 'Trigger drop failed.';
+	$lang['strtriggerenabled'] = 'Trigger enabled.';
+	$lang['strtriggerenabledbad'] = 'Trigger enable failed.';
+	$lang['strtriggerdisabled'] = 'Trigger disabled.';
+	$lang['strtriggerdisabledbad'] = 'Trigger disable failed.';
 	$lang['strtriggeraltered'] = 'Trigger altered.';
 	$lang['strtriggeralteredbad'] = 'Trigger alteration failed.';
 	$lang['strforeach'] = 'For each';
@@ -601,11 +671,34 @@
 	$lang['strreferringtables'] = 'Referring tables';
 	$lang['strparenttables'] = 'Parent tables';
 	$lang['strchildtables'] = 'Child tables';
-	
+
 	// Aggregates
+	$lang['straggregate'] = 'Aggregate';
 	$lang['straggregates'] = 'Aggregates';
 	$lang['strnoaggregates'] = 'No aggregates found.';
 	$lang['stralltypes'] = '(All types)';
+	$lang['straggrtransfn'] = 'Transition function';
+	$lang['strcreateaggregate'] = 'Create aggregate';
+	$lang['straggrbasetype'] = 'Input data type';
+	$lang['straggrsfunc'] = 'State transition function';
+	$lang['straggrstype'] = 'State data type';
+	$lang['straggrffunc'] = 'Final function';
+	$lang['straggrinitcond'] = 'Initial condition';
+	$lang['straggrsortop'] = 'Sort operator';
+	$lang['strdropaggregate'] = 'Drop aggregate';
+	$lang['strconfdropaggregate'] = 'Are you sure you want to drop the aggregate &quot;%s&quot;?';
+	$lang['straggregatedropped'] = 'Aggregate dropped.';
+	$lang['straggregatedroppedbad'] = 'Aggregate drop failed.';
+	$lang['stralteraggregate'] = 'Alter aggregate';
+	$lang['straggraltered'] = 'Aggregate altered.';
+	$lang['straggralteredbad'] = 'Aggregate alteration failed.';
+	$lang['straggrneedsname'] = 'You must specify a name for the aggregate';
+	$lang['straggrneedsbasetype'] = 'You must specify the input data type for the aggregate';
+	$lang['straggrneedssfunc'] = 'You must specify the name of the state transition function for the aggregate';
+	$lang['straggrneedsstype'] = 'You must specify the data type for the aggregate\'s state value';
+	$lang['straggrcreated'] = 'Aggregate created.';
+	$lang['straggrcreatedbad'] = 'Aggregate creation failed.';
+	$lang['straggrshowall'] = 'Show all aggregates';
 
 	// Operator Classes
 	$lang['stropclasses'] = 'Op Classes';
@@ -672,6 +765,11 @@
 	$lang['strfailover'] = 'Failover';
 	$lang['strnodefailedover'] = 'Node failed over.';
 	$lang['strnodefailedoverbad'] = 'Node failover failed.';
+	$lang['strstatus'] = 'Status';	
+	$lang['strhealthy'] = 'Healthy';
+	$lang['stroutofsync'] = 'Out of Sync';
+	$lang['strunknown'] = 'Unknown';	
+
 	
 	// Slony paths	
 	$lang['strpaths'] = 'Paths';
@@ -766,4 +864,27 @@
 	$lang['strerrorloading'] = 'Error Loading';
 	$lang['strclicktoreload'] = 'Click to reload';
 
+	// Autovacuum
+	$lang['strautovacuum'] = 'Autovacuum'; 
+	$lang['strturnedon'] = 'Turned On'; 
+	$lang['strturnedoff'] = 'Turned Off'; 
+	$lang['strenabled'] = 'Enabled'; 
+	$lang['strvacuumbasethreshold'] = 'Vacuum Base Threshold'; 
+	$lang['strvacuumscalefactor'] = 'Vacuum Scale Factor';  
+	$lang['stranalybasethreshold'] = 'Analyze Base Threshold';  
+	$lang['stranalyzescalefactor'] = 'Analyze Scale Factor'; 
+	$lang['strvacuumcostdelay'] = 'Vacuum Cost Delay'; 
+	$lang['strvacuumcostlimit'] = 'Vacuum Cost Limit';  
+
+    // Table-level Locks
+	$lang['strlocks'] = 'Locks';
+	$lang['strtransaction'] = 'Transaction ID';
+	$lang['strprocessid'] = 'Process ID';
+	$lang['strmode'] = 'Lock mode';
+	$lang['strislockheld'] = 'Is lock held?';
+
+	// Prepared transactions
+	$lang['strpreparedxacts'] = 'Prepared transactions';
+	$lang['strxactid'] = 'Transaction ID';
+	$lang['strgid'] = 'Global ID';
 ?>
