@@ -4,7 +4,7 @@
 	 * Japanese language file for phpPgAdmin.
 	 * @maintainer Tadashi Jokagi [elf2000@users.sourceforge.net]
 	 *
-	 * $Id: japanese.php,v 1.16.2.1 2005/11/19 09:51:27 chriskl Exp $
+	 * $Id: japanese.php,v 1.17.2.1 2007/01/19 04:27:10 xzilla Exp $
 	 */
 
 	// Language and character set
@@ -15,13 +15,13 @@
 	$lang['applangdir'] = 'ltr';
   
 	// Welcome  
-	$lang['strintro'] = '&#12424;&#12358;&#12371;&#12381;phpPgAdmin&#12408;&#12290;';
+	$lang['strintro'] = '&#12424;&#12358;&#12371;&#12381; phpPgAdmin &#12408;&#12290;';
 	$lang['strppahome'] = 'phpPgAdmin &#12507;&#12540;&#12512;&#12506;&#12540;&#12472;';
 	$lang['strpgsqlhome'] = 'PostgreSQL &#12507;&#12540;&#12512;&#12506;&#12540;&#12472;';
 	$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
 	$lang['strlocaldocs'] = 'PostgreSQL &#12489;&#12461;&#12517;&#12513;&#12531;&#12488; (&#12525;&#12540;&#12459;&#12523;)';
 	$lang['strreportbug'] = '&#12496;&#12464;&#12524;&#12509;&#12540;&#12488;';
-	$lang['strviewfaq'] = 'FAQ&#12434;&#35211;&#12427;';
+	$lang['strviewfaq'] = 'FAQ &#12434;&#35211;&#12427;';
 	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/?page=faq';
 	
 	// Basic strings
@@ -29,14 +29,14 @@
 	$lang['strloginfailed'] = '&#12525;&#12464;&#12452;&#12531;&#12395;&#22833;&#25943;';
 	$lang['strlogindisallowed'] = '&#12525;&#12464;&#12452;&#12531;&#12364;&#35377;&#21487;&#12373;&#12428;&#12414;&#12379;&#12435;&#12391;&#12375;&#12383;&#12290;';
 	$lang['strserver'] = '&#12469;&#12540;&#12496;&#12540;';
-	$lang['strservers'] = '&#12469;&#12540;&#12496;&#12540;&#19968;&#35239;';
+	$lang['strservers'] = '&#12469;&#12540;&#12496;&#12540;';
 	$lang['strintroduction'] = '&#23566;&#20837;';
 	$lang['strhost'] = '&#12507;&#12473;&#12488;';
 	$lang['strport'] = '&#12509;&#12540;&#12488;';
 	$lang['strlogout'] = '&#12525;&#12464;&#12450;&#12454;&#12488;';
 	$lang['strowner'] = '&#25152;&#26377;&#32773;';
 	$lang['straction'] = '&#12450;&#12463;&#12471;&#12519;&#12531;';
-	$lang['stractions'] = '&#25805;&#20316;&#19968;&#35239;';
+	$lang['stractions'] = '&#25805;&#20316;';
 	$lang['strname'] = '&#21517;&#21069;';
 	$lang['strdefinition'] = '&#23450;&#32681;';
 	$lang['strproperties'] = '&#12503;&#12525;&#12497;&#12486;&#12451;';
@@ -71,7 +71,7 @@
 	$lang['strfalse'] = '&#20605;';
 	$lang['stredit'] = '&#32232;&#38598;';
 	$lang['strcolumn'] = '&#12459;&#12521;&#12512;';
-	$lang['strcolumns'] = '&#12459;&#12521;&#12512;&#19968;&#35239;';
+	$lang['strcolumns'] = '&#12459;&#12521;&#12512;';
 	$lang['strrows'] = '&#12524;&#12467;&#12540;&#12489;';
 	$lang['strrowsaff'] = '&#24433;&#38911;&#12434;&#21463;&#12369;&#12383;&#12524;&#12467;&#12540;&#12489;';
 	$lang['strobjects'] = '&#12458;&#12502;&#12472;&#12455;&#12463;&#12488;';
@@ -89,7 +89,6 @@
 	$lang['strallowednulls']  =  'NULL &#25991;&#23383;&#12434;&#35377;&#21487;&#12377;&#12427;';
 	$lang['strbackslashn']  =  '\N';
 	$lang['strnull']  =  'Null';
-	$lang['strnull']  =  'NULL (The word)';
 	$lang['stremptystring']  =  '&#31354;&#12398;&#25991;&#23383;&#21015;/&#38917;&#30446;';
 	$lang['strsql'] = 'SQL';
 	$lang['stradmin'] = '&#31649;&#29702;';
@@ -121,20 +120,28 @@ $lang['strclustered'] = 'Clustered?';
 	$lang['strdownload'] = '&#12480;&#12454;&#12531;&#12525;&#12540;&#12489;';
 	$lang['strdownloadgzipped'] = 'gzip &#12391;&#22311;&#32302;&#12375;&#12390;&#12480;&#12454;&#12531;&#12525;&#12540;&#12489;';
 	$lang['strinfo'] = '&#24773;&#22577;';
-	$lang['stroids'] = 'OID &#19968;&#35239;';
-	$lang['stradvanced'] = '&#39640;&#24230;&#12394;&#19968;&#35239;';
-	$lang['strvariables'] = '&#22793;&#25968;&#19968;&#35239;';
+	$lang['stroids'] = 'OID ';
+	$lang['stradvanced'] = '&#39640;&#24230;&#12394;';
+	$lang['strvariables'] = '&#22793;&#25968;';
 	$lang['strprocess'] = '&#12503;&#12525;&#12475;&#12473;';
-	$lang['strprocesses'] = '&#12503;&#12525;&#12475;&#12473;&#19968;&#35239;';
+	$lang['strprocesses'] = '&#12503;&#12525;&#12475;&#12473;';
 	$lang['strsetting'] = '&#35373;&#23450;';
 	$lang['streditsql'] = 'SQL &#32232;&#38598;';
-	$lang['strruntime'] = '&#32207;&#23455;&#34892;&#26178;&#38291;: %s ms';
+	$lang['strruntime'] = '&#32207;&#23455;&#34892;&#26178;&#38291;: %s &#12511;&#12522;&#31186;';
 	$lang['strpaginate'] = 'Paginate results';
 	$lang['struploadscript'] = '&#12414;&#12383;&#12399; SQL &#12473;&#12463;&#12522;&#12503;&#12488;&#12434;&#12450;&#12483;&#12503;&#12525;&#12540;&#12489;:';
 	$lang['strstarttime'] = '&#38283;&#22987;&#26178;&#38291;';
 	$lang['strfile'] = '&#12501;&#12449;&#12452;&#12523;';
 	$lang['strfileimported'] = '&#12501;&#12449;&#12452;&#12523;&#12434;&#12452;&#12531;&#12509;&#12540;&#12488;&#12375;&#12414;&#12375;&#12383;&#12290;';
-$lang['strtrycred']  =  'Use these credentials for all servers';
+	$lang['strtrycred']  =  '&#12377;&#12409;&#12390;&#12398;&#12469;&#12540;&#12496;&#12540;&#12391;&#12371;&#12398;&#24773;&#22577;&#12434;&#20351;&#12358;';
+
+	// Database Sizes
+$lang['strsize']  =  '&#12469;&#12452;&#12474;';
+$lang['strbytes']  =  '&#12496;&#12452;&#12488;';
+$lang['strkb']  =  'kB';
+$lang['strmb']  =  'MB';
+$lang['strgb']  =  'GB';
+$lang['strtb']  =  'TB';
 
 	// Error handling
 	$lang['strnoframes'] = '&#12371;&#12398;&#12450;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12434;&#20351;&#29992;&#12377;&#12427;&#12383;&#12417;&#12395;&#12399;&#12501;&#12524;&#12540;&#12512;&#12364;&#20351;&#29992;&#21487;&#33021;&#12394;&#12502;&#12521;&#12454;&#12470;&#12540;&#12364;&#24517;&#35201;&#12391;&#12377;&#12290;';
@@ -161,7 +168,7 @@ $lang['strtrycred']  =  'Use these credentials for all servers';
 
 	// Tables
 	$lang['strtable'] = '&#12486;&#12540;&#12502;&#12523;';
-	$lang['strtables'] = '&#12486;&#12540;&#12502;&#12523;&#19968;&#35239;';
+	$lang['strtables'] = '&#12486;&#12540;&#12502;&#12523;';
 	$lang['strshowalltables'] = '&#20840;&#12486;&#12540;&#12502;&#12523;&#12434;&#35211;&#12427;';
 	$lang['strnotables'] = '&#12486;&#12540;&#12502;&#12523;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strnotable'] = '&#12486;&#12540;&#12502;&#12523;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
@@ -192,7 +199,7 @@ $lang['strtrycred']  =  'Use these credentials for all servers';
 	$lang['strinsertandrepeat'] = '&#25407;&#20837;&#12392;&#32368;&#12426;&#36820;&#12375;';
 	$lang['strnumcols'] = '&#12459;&#12521;&#12512;&#12398;&#25968;';
 	$lang['strcolneedsname'] = '&#12459;&#12521;&#12512;&#12398;&#21517;&#21069;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12426;&#12414;&#12379;&#12435;&#12290;';
-	$lang['strselectallfields'] = '&#32207;&#12390;&#12398;&#12501;&#12451;&#12540;&#12523;&#12489;&#12434;&#36984;&#25246;';
+	$lang['strselectallfields'] = '&#12377;&#12409;&#12390;&#12398;&#12501;&#12451;&#12540;&#12523;&#12489;&#12434;&#36984;&#25246;&#12377;&#12427;';
 	$lang['strselectneedscol'] = '&#23569;&#12394;&#12367;&#12392;&#12418;&#19968;&#12459;&#12521;&#12512;&#12399;&#24517;&#35201;&#12391;&#12377;&#12290;';
 	$lang['strselectunary'] = '&#21336;&#38917;&#12398;&#12458;&#12506;&#12524;&#12540;&#12479;&#12540;&#12399;&#20516;&#12434;&#25345;&#12388;&#12371;&#12392;&#12364;&#12391;&#12365;&#12414;&#12379;&#12435;&#12290;';
 	$lang['straltercolumn'] = '&#12459;&#12521;&#12512;&#12398;&#22793;&#26356;';
@@ -201,7 +208,7 @@ $lang['strtrycred']  =  'Use these credentials for all servers';
 	$lang['strconfdropcolumn'] = '&#26412;&#24403;&#12395;&#12459;&#12521;&#12512;&#12300;%s&#12301;&#12434;&#12486;&#12540;&#12502;&#12523;&#12300;%s&#12301;&#12363;&#12425;&#30772;&#26820;&#12375;&#12390;&#12356;&#12356;&#12391;&#12377;&#12363;?';
 	$lang['strcolumndropped'] = '&#12459;&#12521;&#12512;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
 	$lang['strcolumndroppedbad'] = '&#12459;&#12521;&#12512;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
-	$lang['straddcolumn'] = '&#12459;&#12521;&#12512;&#12434;&#36861;&#21152;&#12377;&#12427;';
+	$lang['straddcolumn'] = '&#12459;&#12521;&#12512;&#12398;&#36861;&#21152;';
 	$lang['strcolumnadded'] = '&#12459;&#12521;&#12512;&#12434;&#36861;&#21152;&#12375;&#12414;&#12375;&#12383;&#12290;';
 	$lang['strcolumnaddedbad'] = '&#12459;&#12521;&#12512;&#12398;&#36861;&#21152;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
 	$lang['strcascade'] = '&#12459;&#12473;&#12465;&#12540;&#12489;';
@@ -210,17 +217,17 @@ $lang['strtrycred']  =  'Use these credentials for all servers';
 	$lang['strdataonly'] = '&#12487;&#12540;&#12479;&#12398;&#12415;';
 	$lang['strstructureonly'] = '&#27083;&#36896;&#12398;&#12415;';
 	$lang['strstructureanddata'] = '&#27083;&#36896;&#12392;&#12487;&#12540;&#12479;';
-$lang['strtabbed'] = 'Tabbed';
+	$lang['strtabbed'] = '&#12479;&#12502;&#21306;&#20999;&#12426;';
 	$lang['strauto'] = '&#33258;&#21205;';
-	$lang['strconfvacuumtable'] = '&#26412;&#24403;&#12395; &quot;%s&quot; &#12434; vacuum &#12375;&#12414;&#12377;&#12363;?';
+	$lang['strconfvacuumtable'] = '&#26412;&#24403;&#12395;&#12300;%s&#12301;&#12434;&#12496;&#12461;&#12517;&#12540;&#12512;&#12375;&#12414;&#12377;&#12363;?';
 	$lang['strestimatedrowcount'] = '&#35413;&#20385;&#28168;&#12524;&#12467;&#12540;&#12489;&#25968;';
 
 	// Users
 	$lang['struser'] = '&#12518;&#12540;&#12470;&#12540;';
-	$lang['strusers'] = '&#12518;&#12540;&#12470;&#12540;&#19968;&#35239;';
+	$lang['strusers'] = '&#12518;&#12540;&#12470;&#12540;';
 	$lang['strusername'] = '&#12518;&#12540;&#12470;&#12540;&#21517;';
 	$lang['strpassword'] = '&#12497;&#12473;&#12527;&#12540;&#12489;';
-	$lang['strsuper'] = '&#12473;&#12540;&#12497;&#12540;&#12518;&#12540;&#12470;&#12540;?';
+	$lang['strsuper'] = '&#12473;&#12540;&#12497;&#12540;&#12518;&#12540;&#12470;&#12540;&#12391;&#12377;&#12363;?';
 	$lang['strcreatedb'] = '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12434;&#20316;&#25104;&#12375;&#12414;&#12377;&#12363;?';
 	$lang['strexpires'] = '&#26377;&#21177;&#26399;&#38480;';
 	$lang['strsessiondefaults'] = '&#12475;&#12483;&#12471;&#12519;&#12531;&#12487;&#12501;&#12457;&#12523;&#12488;';
@@ -244,7 +251,7 @@ $lang['strtabbed'] = 'Tabbed';
 		
 	// Groups
 	$lang['strgroup'] = '&#12464;&#12523;&#12540;&#12503;';
-	$lang['strgroups'] = '&#12464;&#12523;&#12540;&#12503;&#19968;&#35239;';
+	$lang['strgroups'] = '&#12464;&#12523;&#12540;&#12503;';
 	$lang['strnogroup'] = '&#12464;&#12523;&#12540;&#12503;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strnogroups'] = '&#12464;&#12523;&#12540;&#12503;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strcreategroup'] = '&#12464;&#12523;&#12540;&#12503;&#12434;&#20316;&#25104;&#12377;&#12427;';
@@ -266,7 +273,7 @@ $lang['strtabbed'] = 'Tabbed';
 
 	// Privileges
 	$lang['strprivilege'] = '&#29305;&#27177;';
-	$lang['strprivileges'] = '&#29305;&#27177;&#19968;&#35239;';
+	$lang['strprivileges'] = '&#29305;&#27177;';
 	$lang['strnoprivileges'] = '&#12371;&#12398;&#12458;&#12502;&#12472;&#12455;&#12463;&#12488;&#12399;&#29305;&#27177;&#12434;&#25345;&#12387;&#12390;&#12356;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strgrant'] = '&#27177;&#38480;';
 	$lang['strrevoke'] = '&#24259;&#27490;';
@@ -278,7 +285,7 @@ $lang['strtabbed'] = 'Tabbed';
 
 	// Databases
 	$lang['strdatabase'] = '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;';
-	$lang['strdatabases'] = '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#19968;&#35239;';
+	$lang['strdatabases'] = '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;';
 	$lang['strshowalldatabases'] = '&#20840;&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12434;&#35211;&#12427;';
 	$lang['strnodatabase'] = '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strnodatabases'] = '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12364;&#20840;&#12367;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
@@ -303,14 +310,14 @@ $lang['strtabbed'] = 'Tabbed';
 	$lang['strforce'] = '&#24375;&#21046;';
 	$lang['strsignalsent'] = '&#12471;&#12464;&#12490;&#12523;&#36865;&#20449;';
 	$lang['strsignalsentbad'] = '&#12471;&#12464;&#12490;&#12523;&#36865;&#20449;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;';
-	$lang['strallobjects'] = '&#12377;&#12409;&#12390;&#12398;&#12458;&#12502;&#12472;&#12455;&#12463;&#12488;&#19968;&#35239;';
+	$lang['strallobjects'] = '&#12377;&#12409;&#12390;&#12398;&#12458;&#12502;&#12472;&#12455;&#12463;&#12488;';
 	$lang['strdatabasealtered']  =  '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12434;&#22793;&#26356;&#12375;&#12414;&#12375;&#12383;&#12290;';
 	$lang['strdatabasealteredbad']  =  '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12398;&#22793;&#26356;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
 
 	// Views
 	$lang['strview'] = '&#12499;&#12517;&#12540;';
-	$lang['strviews'] = '&#12499;&#12517;&#12540;&#19968;&#35239;';
-	$lang['strshowallviews'] = '&#20840;&#12499;&#12517;&#12540;&#12398;&#34920;&#31034;';
+	$lang['strviews'] = '&#12499;&#12517;&#12540;';
+	$lang['strshowallviews'] = '&#20840;&#12499;&#12517;&#12540;&#12434;&#34920;&#31034;&#12377;&#12427;';
 	$lang['strnoview'] = '&#12499;&#12517;&#12540;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strnoviews'] = '&#12499;&#12517;&#12540;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strcreateview'] = '&#12499;&#12517;&#12540;&#12434;&#20316;&#25104;&#12377;&#12427;';
@@ -331,7 +338,7 @@ $lang['strviewlink'] = 'Linking Keys';
 
 	// Sequences
 	$lang['strsequence'] = '&#12471;&#12540;&#12465;&#12531;&#12473;';
-	$lang['strsequences'] = '&#12471;&#12540;&#12465;&#12531;&#12473;&#19968;&#35239;';
+	$lang['strsequences'] = '&#12471;&#12540;&#12465;&#12531;&#12473;';
 	$lang['strshowallsequences'] = '&#20840;&#12471;&#12540;&#12465;&#12531;&#12473;&#12434;&#35211;&#12427;';
 	$lang['strnosequence'] = '&#12471;&#12540;&#12465;&#12531;&#12473;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strnosequences'] = '&#12471;&#12540;&#12465;&#12531;&#12473;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
@@ -343,7 +350,7 @@ $lang['strviewlink'] = 'Linking Keys';
 	$lang['strminvalue'] = '&#26368;&#23567;&#20516;';
 	$lang['strcachevalue'] = '&#12461;&#12515;&#12483;&#12471;&#12517;&#20516;';
 	$lang['strlogcount'] = '&#12525;&#12464;&#12459;&#12454;&#12531;&#12488;';
-$lang['striscycled'] = 'Is Cycled?';
+	$lang['striscycled'] = 'Cycle &#12375;&#12414;&#12377;&#12363;?';
 $lang['striscalled'] = 'Is Called?';
 	$lang['strsequenceneedsname'] = '&#12471;&#12540;&#12465;&#12531;&#12473;&#21517;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strsequencecreated'] = '&#12471;&#12540;&#12465;&#12531;&#12473;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
@@ -356,9 +363,9 @@ $lang['striscalled'] = 'Is Called?';
 
 	// Indexes
 	$lang['strindex'] = '&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;';
-	$lang['strindexes'] = '&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#19968;&#35239;';
+	$lang['strindexes'] = '&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;';
 	$lang['strindexname'] = '&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#21517;';
-	$lang['strshowallindexes'] = '&#20840;&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#12398;&#34920;&#31034;';
+	$lang['strshowallindexes'] = '&#20840;&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#12434;&#34920;&#31034;&#12377;&#12427;';
 	$lang['strnoindex'] = '&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strnoindexes'] = '&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strcreateindex'] = '&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#12434;&#20316;&#25104;&#12377;&#12427;';
@@ -382,9 +389,9 @@ $lang['striscalled'] = 'Is Called?';
 	$lang['strclusteredbad'] = '&#12463;&#12521;&#12473;&#12479;&#12540;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
 
 	// Rules
-	$lang['strrules'] = '&#12523;&#12540;&#12523;&#19968;&#35239;';
+	$lang['strrules'] = '&#12523;&#12540;&#12523;';
 	$lang['strrule'] = '&#12523;&#12540;&#12523;';
-	$lang['strshowallrules'] = '&#20840;&#12523;&#12540;&#12523;&#12398;&#34920;&#31034;';
+	$lang['strshowallrules'] = '&#20840;&#12523;&#12540;&#12523;&#12434;&#34920;&#31034;&#12377;&#12427;';
 	$lang['strnorule'] = '&#12523;&#12540;&#12523;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strnorules'] = '&#12523;&#12540;&#12523;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strcreaterule'] = '&#12523;&#12540;&#12523;&#12434;&#20316;&#25104;&#12377;&#12427;';
@@ -398,8 +405,8 @@ $lang['striscalled'] = 'Is Called?';
 
 	// Constraints
 	$lang['strconstraint'] = '&#26908;&#26619;&#21046;&#32004;';
-	$lang['strconstraints'] = '&#26908;&#26619;&#21046;&#32004;&#19968;&#35239;';
-	$lang['strshowallconstraints'] = '&#20840;&#26908;&#26619;&#21046;&#32004;&#12398;&#34920;&#31034;';
+	$lang['strconstraints'] = '&#26908;&#26619;&#21046;&#32004;';
+	$lang['strshowallconstraints'] = '&#20840;&#26908;&#26619;&#21046;&#32004;&#12434;&#34920;&#31034;&#12377;&#12427;';
 	$lang['strnoconstraints'] = '&#26908;&#26619;&#21046;&#32004;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strcreateconstraint'] = '&#26908;&#26619;&#21046;&#32004;&#12434;&#20316;&#25104;&#12377;&#12427;';
 	$lang['strconstraintcreated'] = '&#26908;&#26619;&#21046;&#32004;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
@@ -431,8 +438,8 @@ $lang['striscalled'] = 'Is Called?';
 
 	// Functions
 	$lang['strfunction'] = '&#38306;&#25968;';
-	$lang['strfunctions'] = '&#38306;&#25968;&#19968;&#35239;';
-	$lang['strshowallfunctions'] = '&#20840;&#38306;&#25968;&#12398;&#34920;&#31034;';
+	$lang['strfunctions'] = '&#38306;&#25968;';
+	$lang['strshowallfunctions'] = '&#20840;&#38306;&#25968;&#12434;&#34920;&#31034;&#12377;&#12427;';
 	$lang['strnofunction'] = '&#38306;&#25968;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strnofunctions'] = '&#38306;&#25968;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strcreateplfunction'] = 'SQL/PL &#38306;&#25968;&#12434;&#20316;&#25104;&#12377;&#12427;';
@@ -456,7 +463,7 @@ $lang['striscalled'] = 'Is Called?';
 
 	// Triggers
 	$lang['strtrigger'] = '&#12488;&#12522;&#12460;&#12540;';
-	$lang['strtriggers'] = '&#12488;&#12522;&#12460;&#12540;&#19968;&#35239;';
+	$lang['strtriggers'] = '&#12488;&#12522;&#12460;&#12540;';
 	$lang['strshowalltriggers'] = '&#20840;&#12488;&#12522;&#12460;&#12540;&#12434;&#34920;&#31034;';
 	$lang['strnotrigger'] = '&#12488;&#12522;&#12460;&#12540;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strnotriggers'] = '&#12488;&#12522;&#12460;&#12540;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
@@ -474,7 +481,7 @@ $lang['strforeach']  =  'For each';
 
 	// Types
 	$lang['strtype'] = '&#12487;&#12540;&#12479;&#22411;';
-	$lang['strtypes'] = '&#12487;&#12540;&#12479;&#22411;&#19968;&#35239;';
+	$lang['strtypes'] = '&#12487;&#12540;&#12479;&#22411;';
 	$lang['strshowalltypes'] = '&#20840;&#12487;&#12540;&#12479;&#22411;&#12434;&#34920;&#31034;&#12377;&#12427;';
 	$lang['strnotype'] = '&#12487;&#12540;&#12479;&#22411;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strnotypes'] = '&#12487;&#12540;&#12479;&#22411;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12391;&#12375;&#12383;&#12290;';
@@ -495,19 +502,19 @@ $lang['strpassbyval'] = 'Passed by val?';
 	$lang['strtypeneedsname'] = '&#22411;&#21517;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strtypeneedslen'] = '&#12487;&#12540;&#12479;&#22411;&#12398;&#38263;&#12373;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strtypecreated'] = '&#12487;&#12540;&#12479;&#22411;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
-	$lang['strtypecreatedbad'] = '&#12487;&#12540;&#12479;&#22411;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;';
+	$lang['strtypecreatedbad'] = '&#12487;&#12540;&#12479;&#22411;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
 	$lang['strconfdroptype'] = '&#26412;&#24403;&#12395;&#12487;&#12540;&#12479;&#22411;&#12300;%s&#12301;&#12434;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
 	$lang['strtypedropped'] = '&#12487;&#12540;&#12479;&#22411;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
 	$lang['strtypedroppedbad'] = '&#12487;&#12540;&#12479;&#22411;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
-$lang['strflavor'] = 'Flavor';
+	$lang['strflavor'] = '&#31278;&#39006;';
 	$lang['strbasetype'] = '&#22522;&#26412;';
 	$lang['strcompositetype'] = '&#35079;&#21512;&#22411;';
-$lang['strpseudotype'] = 'Pseudo';
+	$lang['strpseudotype'] = '&#25836;&#20284;&#12487;&#12540;&#12479;';
 
 	// Schemas
 	$lang['strschema'] = '&#12473;&#12461;&#12540;&#12510;';
-	$lang['strschemas'] = '&#12473;&#12461;&#12540;&#12510;&#19968;&#35239;';
-	$lang['strshowallschemas'] = '&#20840;&#12473;&#12461;&#12540;&#12510;&#12398;&#34920;&#31034;';
+	$lang['strschemas'] = '&#12473;&#12461;&#12540;&#12510;';
+	$lang['strshowallschemas'] = '&#20840;&#12473;&#12461;&#12540;&#12510;&#12434;&#34920;&#31034;&#12377;&#12427;';
 	$lang['strnoschema'] = '&#12473;&#12461;&#12540;&#12510;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strnoschemas'] = '&#12473;&#12461;&#12540;&#12510;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strcreateschema'] = '&#12473;&#12461;&#12540;&#12510;&#12434;&#20316;&#25104;&#12377;&#12427;';
@@ -524,7 +531,7 @@ $lang['strpseudotype'] = 'Pseudo';
 
 	// Reports
 	$lang['strreport'] = '&#12524;&#12509;&#12540;&#12488;';
-	$lang['strreports'] = '&#12524;&#12509;&#12540;&#12488;&#19968;&#35239;';
+	$lang['strreports'] = '&#12524;&#12509;&#12540;&#12488;';
 	$lang['strshowallreports'] = '&#20840;&#12524;&#12509;&#12540;&#12488;&#12434;&#35211;&#12427;';
 	$lang['strnoreports'] = '&#12524;&#12509;&#12540;&#12488;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strcreatereport'] = '&#12524;&#12509;&#12540;&#12488;&#12434;&#20316;&#25104;&#12377;&#12427;';
@@ -538,7 +545,7 @@ $lang['strpseudotype'] = 'Pseudo';
 
 	// Domains
 	$lang['strdomain'] = '&#12489;&#12513;&#12452;&#12531;';
-	$lang['strdomains'] = '&#12489;&#12513;&#12452;&#12531;&#19968;&#35239;';
+	$lang['strdomains'] = '&#12489;&#12513;&#12452;&#12531;';
 	$lang['strshowalldomains'] = '&#20840;&#12489;&#12513;&#12452;&#12531;&#12434;&#35211;&#12427;';
 	$lang['strnodomains'] = '&#12489;&#12513;&#12452;&#12531;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strcreatedomain'] = '&#12489;&#12513;&#12452;&#12531;&#20316;&#25104;';
@@ -553,7 +560,7 @@ $lang['strpseudotype'] = 'Pseudo';
 
 	// Operators
 	$lang['stroperator'] = '&#28436;&#31639;&#23376;';
-	$lang['stroperators'] = '&#28436;&#31639;&#23376;&#19968;&#35239;';
+	$lang['stroperators'] = '&#28436;&#31639;&#23376;';
 	$lang['strshowalloperators'] = '&#20840;&#28436;&#31639;&#23376;&#12434;&#35211;&#12427;';
 	$lang['strnooperator'] = '&#28436;&#31639;&#23376;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strnooperators'] = '&#28436;&#31639;&#23376;&#12463;&#12521;&#12473;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
@@ -578,7 +585,7 @@ $lang['strpseudotype'] = 'Pseudo';
 	$lang['stroperatordroppedbad'] = '&#28436;&#31639;&#23376;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
 
 	// Casts
-	$lang['strcasts'] = '&#12461;&#12515;&#12473;&#12488;&#19968;&#35239;';
+	$lang['strcasts'] = '&#12461;&#12515;&#12473;&#12488;';
 	$lang['strnocasts'] = '&#12461;&#12515;&#12473;&#12488;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strsourcetype'] = '&#12477;&#12540;&#12473;&#12479;&#12452;&#12503;';
 	$lang['strtargettype'] = '&#12479;&#12540;&#12466;&#12483;&#12488;&#12479;&#12452;&#12503;';
@@ -587,29 +594,29 @@ $lang['strinassignment'] = 'In assignment';
 	$lang['strbinarycompat'] = '(&#12496;&#12452;&#12490;&#12522;&#20114;&#25563;)';
 	
 	// Conversions
-	$lang['strconversions'] = '&#22793;&#25563;&#19968;&#35239;';
+	$lang['strconversions'] = '&#22793;&#25563;';
 	$lang['strnoconversions'] = '&#22793;&#25563;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strsourceencoding'] = '&#22793;&#25563;&#20803;&#12456;&#12531;&#12467;&#12540;&#12489;';
 	$lang['strtargetencoding'] = '&#22793;&#25563;&#20808;&#12456;&#12531;&#12467;&#12540;&#12489;';
 	
 	// Languages
-	$lang['strlanguages'] = '&#35328;&#35486;&#19968;&#35239;';
+	$lang['strlanguages'] = '&#35328;&#35486;';
 	$lang['strnolanguages'] = '&#35328;&#35486;&#12364;&#23384;&#22312;&#12375;&#12414;&#12379;&#12435;&#12290;';
 $lang['strtrusted'] = 'Trusted';
 	
 	// Info
 	$lang['strnoinfo'] = '&#26377;&#21177;&#12394;&#24773;&#22577;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
-	$lang['strreferringtables'] = '&#21442;&#29031;&#12486;&#12540;&#12502;&#12523;&#19968;&#35239;';
-	$lang['strparenttables'] = '&#35242;&#12486;&#12540;&#12502;&#12523;&#19968;&#35239;';
-	$lang['strchildtables'] = '&#23376;&#12486;&#12540;&#12502;&#12523;&#19968;&#35239;';
+	$lang['strreferringtables'] = '&#21442;&#29031;&#12486;&#12540;&#12502;&#12523;';
+	$lang['strparenttables'] = '&#35242;&#12486;&#12540;&#12502;&#12523;';
+	$lang['strchildtables'] = '&#23376;&#12486;&#12540;&#12502;&#12523;';
 
 	// Aggregates
-	$lang['straggregates'] = '&#38598;&#35336;&#19968;&#35239;';
+	$lang['straggregates'] = '&#38598;&#35336;';
 	$lang['strnoaggregates'] = '&#38598;&#35336;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['stralltypes'] = '(&#20840;&#12390;&#12398;&#12479;&#12452;&#12503;)';
 
 	// Operator Classes
-	$lang['stropclasses'] = '&#28436;&#31639;&#23376;&#12463;&#12521;&#12473;&#19968;&#35239;';
+	$lang['stropclasses'] = '&#28436;&#31639;&#23376;&#12463;&#12521;&#12473;';
 	$lang['strnoopclasses'] = '&#28436;&#31639;&#23376;&#12463;&#12521;&#12473;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['straccessmethod'] = '&#12450;&#12463;&#12475;&#12473;&#26041;&#27861;';
 
@@ -691,14 +698,14 @@ $lang['strtrusted'] = 'Trusted';
 	$lang['strpathdroppedbad']  =  '&#12497;&#12473;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
 
 	// Slony listens
-$lang['strlistens']  =  'Listens';
-$lang['strnolistens']  =  'No listens found.';
-$lang['strcreatelisten']  =  'Create listen';
-$lang['strlistencreated']  =  'Listen created.';
-$lang['strlistencreatedbad']  =  'Listen creation failed.';
-$lang['strconfdroplisten']  =  'Are you sure you want to drop listen &quot;%s&quot;?';
-$lang['strlistendropped']  =  'Listen dropped.';
-$lang['strlistendroppedbad']  =  'Listen drop failed.';
+	$lang['strlistens']  =  '&#12522;&#12483;&#12473;&#12531;';
+	$lang['strnolistens']  =  '&#12522;&#12483;&#12473;&#12531;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
+	$lang['strcreatelisten']  =  '&#12522;&#12483;&#12473;&#12531;&#12434;&#20316;&#25104;&#12377;&#12427;';
+	$lang['strlistencreated']  =  '&#12522;&#12483;&#12473;&#12531;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
+	$lang['strlistencreatedbad']  =  '&#12522;&#12483;&#12473;&#12531;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
+	$lang['strconfdroplisten']  =  '&#26412;&#24403;&#12395;&#12522;&#12483;&#12473;&#12531;&#12300;%s&#12301;&#12434;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
+	$lang['strlistendropped']  =  '&#12522;&#12483;&#12473;&#12531;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
+	$lang['strlistendroppedbad']  =  '&#12522;&#12483;&#12473;&#12531;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
 
 	// Slony replication sets
 	$lang['strrepsets']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;';
@@ -753,11 +760,11 @@ $lang['strlistendroppedbad']  =  'Listen drop failed.';
 	$lang['strsequenceremovedfromrepsetbad']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12363;&#12425;&#12471;&#12540;&#12465;&#12531;&#12473;&#12398;&#21066;&#38500;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
 
 	// Slony subscriptions
-$lang['strsubscriptions']  =  'Subscriptions';
-$lang['strnosubscriptions']  =  'No subscriptions found.';
+	$lang['strsubscriptions']  =  '&#12469;&#12502;&#12473;&#12463;&#12522;&#12503;&#12471;&#12519;&#12531;';
+	$lang['strnosubscriptions']  =  '&#12469;&#12502;&#12473;&#12463;&#12522;&#12503;&#12471;&#12519;&#12531;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
 
 	// Miscellaneous
-	$lang['strtopbar'] = '%s &#12395; %s &#12509;&#12540;&#12488;&#30058;&#21495; %s &#12391;&#25509;&#32154; -- &#12518;&#12540;&#12470;&#12540;&#12300;%s&#12301;&#12391;&#12507;&#12473;&#12488;&#12300;%s&#12301;&#12395;&#12525;&#12464;&#12452;&#12531;';
+	$lang['strtopbar'] = '&#12469;&#12540;&#12496;&#12540; %2$s &#12398;&#12509;&#12540;&#12488;&#30058;&#21495; %3$s &#12391;&#23455;&#34892;&#20013;&#12398; %1$s &#12395;&#25509;&#32154;&#20013; -- &#12518;&#12540;&#12470;&#12540;&#12300;%4$s&#12301;&#12392;&#12375;&#12390;&#12525;&#12464;&#12452;&#12531;&#20013;(%5$s)';
 	$lang['strtimefmt'] = 'Y &#24180; n &#26376; j &#26085; G:i';
 	$lang['strhelp'] = '&#12504;&#12523;&#12503;';
 	$lang['strhelpicon'] = '?';
