@@ -4,7 +4,7 @@
 	 * Spanish language file for phpPgAdmin.
 	 * @maintainer Martn Marqus (martin@bugs.unl.edu.ar)
 	 *
-	 * $Id: spanish.php,v 1.31 2005/10/28 01:57:53 chriskl Exp $
+	 * $Id: spanish.php,v 1.35.2.2 2007/01/21 21:25:24 xzilla Exp $
 	 */
 
 	// Language and character set
@@ -14,7 +14,7 @@
   	$lang['appdbencoding'] = 'LATIN1';
 	$lang['applangdir'] = 'ltr';
 
-        // Bienvenido
+    // Bienvenido
 	$lang['strintro'] = 'Bienvenido a phpPgAdmin.';
 	$lang['strppahome'] = 'Pgina web de phpPgAdmin';
 	$lang['strpgsqlhome'] = 'Pgina web de PostgreSQL';
@@ -29,10 +29,10 @@
 	$lang['strloginfailed'] = 'Fall la autenticacin';
 	$lang['strlogindisallowed'] = 'Ingreso no autorizado';
 	$lang['strserver'] = 'Servidor';
-        $lang['strservers']  =  'Servidores';
-        $lang['strintroduction']  =  'Introduccin';
-        $lang['strhost']  =  'Host';
-        $lang['strport']  =  'Puerto';
+    $lang['strservers']  =  'Servidores';
+    $lang['strintroduction']  =  'Introduccin';
+    $lang['strhost']  =  'Host';
+    $lang['strport']  =  'Puerto';
 	$lang['strlogout'] = 'Salir';
 	$lang['strowner'] = 'Dueo';
 	$lang['straction'] = 'Accin';
@@ -41,14 +41,16 @@
 	$lang['strdefinition'] = 'Definicin';
 	$lang['strproperties'] = 'Propiedades';
 	$lang['strbrowse'] = 'Examinar';
+	$lang['strenable']  =  'Activar';
+	$lang['strdisable']  =  'Desactivar';
 	$lang['strdrop'] = 'Eliminar';
 	$lang['strdropped'] = 'Eliminado';
 	$lang['strnull'] = 'Nulo';
 	$lang['strnotnull'] = 'No Nulo';
 	$lang['strprev'] = 'Previo';
 	$lang['strnext'] = 'Prximo';
-        $lang['strfirst'] = '<< Principio';
-        $lang['strlast'] = 'Final >>';
+    $lang['strfirst'] = '<< Principio';
+    $lang['strlast'] = 'Final >>';
 	$lang['strfailed'] = 'Fall';
 	$lang['strcreate'] = 'Crear';
 	$lang['strcreated'] = 'Creado';
@@ -58,6 +60,7 @@
 	$lang['stralter'] = 'Modificar';
 	$lang['strok'] = 'OK';
 	$lang['strcancel'] = 'Cancelar';
+$lang['strac']  =  'Enable AutoComplete';
 	$lang['strsave'] = 'Guardar';
 	$lang['strreset'] = 'Reestablecer';
 	$lang['strinsert'] = 'Insertar';
@@ -70,7 +73,7 @@
 	$lang['strtrue'] = 'Verdadero';
 	$lang['strfalse'] = 'Falso';
 	$lang['stredit'] = 'Editar';
-        $lang['strcolumn']  =  'Columna';
+    $lang['strcolumn']  =  'Columna';
 	$lang['strcolumns'] = 'Columnas';
 	$lang['strrows'] = 'fila(s)';
 	$lang['strrowsaff'] = 'fila(s) afectadas.';
@@ -86,11 +89,10 @@
 	$lang['strprimary'] = 'Primaria';
 	$lang['strexport'] = 'Exportar';
 	$lang['strimport'] = 'Importar';
-        $lang['strallowednulls']  =  'Valores Nulos (NULL) Permitidos';
-$lang['strbackslashn']  =  '\N';
-$lang['strnull']  =  'Null';
-$lang['strnull']  =  'NULL (The word)';
-        $lang['stremptystring']  =  'Cadena o campo vacio';
+    $lang['strallowednulls']  =  'Valores Nulos (NULL) Permitidos';
+	$lang['strbackslashn']  =  '\N';
+    $lang['strnull']  =  'Nulo';
+    $lang['stremptystring']  =  'Cadena o campo vacio';
 	$lang['strsql'] = 'SQL';
 	$lang['stradmin'] = 'Admin';
 	$lang['strvacuum'] = 'Limpiar';
@@ -100,7 +102,7 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strreindex'] = 'Reindexar';
 	$lang['strrun'] = 'Ejecutar';
 	$lang['stradd'] = 'Agregar';
-        $lang['strremove']  =  'Remover';
+    $lang['strremove']  =  'Remover';
 	$lang['strevent'] = 'Evento';
 	$lang['strwhere'] = 'Dnde';
 	$lang['strinstead'] = 'Hacer en su lugar';
@@ -113,10 +115,10 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strseparator']  =  ': ';
 	$lang['strexpand'] = 'Expandir';
 	$lang['strcollapse'] = 'Colapsar';
-        $lang['strexplain'] = 'Explicar';
+    $lang['strexplain'] = 'Explicar';
 	$lang['strexplainanalyze'] = 'Explicar analizando';
-        $lang['strfind'] = 'Buscar';
-        $lang['stroptions'] = 'Opciones';
+    $lang['strfind'] = 'Buscar';
+    $lang['stroptions'] = 'Opciones';
 	$lang['strrefresh'] = 'Refrescar';
 	$lang['strdownload'] = 'Bajar';
 	$lang['strdownloadgzipped'] = 'Bajar comprimido con gzip';
@@ -134,14 +136,22 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strstarttime'] = 'Hora de comienzo';
 	$lang['strfile'] = 'Archivo';
 	$lang['strfileimported'] = 'Archivo importado.';
-        $lang['strtrycred']  =  'Usar el mismo par usuario/contrasea para todos los servidores';
+    $lang['strtrycred']  =  'Usar el mismo par usuario/contrasea para todos los servidores';
+
+	// Database Sizes
+	$lang['strsize'] = 'Tamao';
+	$lang['strbytes'] = 'bytes';
+	$lang['strkb'] = 'kB';
+	$lang['strmb'] = 'MB';
+	$lang['strgb'] = 'GB';
+	$lang['strtb'] = 'TB';
 
 	// Error handling
-        $lang['strnoframes']  =  'Esta aplicacin funciona mejor con un navegador con soporte para marcos, pero puede usarse sin marcos siguiendo el link de abajo.';
-        $lang['strnoframeslink']  =  'Usar sin marcos';
+    $lang['strnoframes']  =  'Esta aplicacin funciona mejor con un navegador con soporte para marcos, pero puede usarse sin marcos siguiendo el link de abajo.';
+    $lang['strnoframeslink']  =  'Usar sin marcos';
 	$lang['strbadconfig'] = 'Su archivo config.inc.php est desactualizado. Deber regenerarlo a partir del archivo nuevo config.inc.php-dist.';
 	$lang['strnotloaded'] = 'Su versin de PHP no tiene el soporte correcto de bases de datos.';
-        $lang['strpostgresqlversionnotsupported']  =  'Su versin de PostgreSQL no est soportado. Por favor actualice a la versin %s o ms reciente.';
+    $lang['strpostgresqlversionnotsupported']  =  'Su versin de PostgreSQL no est soportado. Por favor actualice a la versin %s o ms reciente.';
 	$lang['strbadschema'] = 'El esquema especificado no es vlido.';
 	$lang['strbadencoding'] = 'No se pudo setear la codificacin del cliente en la base de datos.';
 	$lang['strsqlerror'] = 'Error de SQL:';
@@ -153,11 +163,11 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strnoreportsdb'] = 'No ha creado an la base de datos para los reportes. Lea las instrucciones del archivo INSTALL.';
 	$lang['strnouploads'] = 'Est deshabilitada la subida de archivos.';
 	$lang['strimporterror'] = 'Error de importacin.';
-        $lang['strimporterror-fileformat']  =  'Error de importacion de datos: Fall al intentar determinar el formato del archivo.';
+    $lang['strimporterror-fileformat']  =  'Error de importacion de datos: Fall al intentar determinar el formato del archivo.';
 	$lang['strimporterrorline'] = 'Error de importacin en la lnea %s.';
-        $lang['strimporterrorline-badcolumnnum']  =  'Error de importacin en la lnea %s:  La lnea no posee la cantidad de columnas correctas.';
-        $lang['strimporterror-uploadedfile']  =  'Error de importacin: No se ha podido subir el archivo al servidor';
-        $lang['strcannotdumponwindows']  =  'Vuelco de datos con nombres complejos de tablas y esquemas no esta soportado en Windows.';
+    $lang['strimporterrorline-badcolumnnum']  =  'Error de importacin en la lnea %s:  La lnea no posee la cantidad de columnas correctas.';
+    $lang['strimporterror-uploadedfile']  =  'Error de importacin: No se ha podido subir el archivo al servidor';
+    $lang['strcannotdumponwindows']  =  'Vuelco de datos con nombres complejos de tablas y esquemas no esta soportado en Windows.';
 
 	// Tables
 	$lang['strtable'] = 'Tabla';
@@ -181,7 +191,7 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strinsertrow'] = 'Insertar Fila';
 	$lang['strrowinserted'] = 'Fila insertada.';
 	$lang['strrowinsertedbad'] = 'Fall la insercin de fila.';
-        $lang['strrowduplicate']  =  'Insercin de fila fall, intentado hacer una duplicacin de insercin.';
+    $lang['strrowduplicate']  =  'Insercin de fila fall, intentado hacer una duplicacin de insercin.';
 	$lang['streditrow'] = 'Editar fila';
 	$lang['strrowupdated'] = 'Fila actualizada.';
 	$lang['strrowupdatedbad'] = 'Fall al intentar actualizar la fila.';
@@ -189,10 +199,10 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strconfdeleterow'] = 'Est seguro que quiere eliminar esta fila?';
 	$lang['strrowdeleted'] = 'Fila eliminada.';
 	$lang['strrowdeletedbad'] = 'Fall la eliminacin de fila.';
-        $lang['strinsertandrepeat']  =  'Insertar y Repite';
-        $lang['strnumcols']  =  'Cantidad de columnas';
-        $lang['strcolneedsname']  =  'Debe especificar un nombre para la columna';
-        $lang['strselectallfields'] = 'Seleccionar todos los campos.';
+    $lang['strinsertandrepeat']  =  'Insertar y Repite';
+    $lang['strnumcols']  =  'Cantidad de columnas';
+    $lang['strcolneedsname']  =  'Debe especificar un nombre para la columna';
+    $lang['strselectallfields'] = 'Seleccionar todos los campos.';
 	$lang['strselectneedscol'] = 'Debe elegir al menos una columna';
 	$lang['strselectunary'] = 'Operaciones unitarias no pueden tener valores.';
 	$lang['straltercolumn'] = 'Modificar Columna';
@@ -201,21 +211,24 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strconfdropcolumn'] = 'Est seguro que quiere eliminar la columna "%s" de la tabla "%s"?';
 	$lang['strcolumndropped'] = 'Columna eliminada.';
 	$lang['strcolumndroppedbad'] = 'Fall la eliminacin de columna.';
-        $lang['straddcolumn'] = 'Agregar Columna';
+    $lang['straddcolumn'] = 'Agregar Columna';
 	$lang['strcolumnadded'] = 'Columna agregada.';
 	$lang['strcolumnaddedbad'] = 'Fall el agregado de columna.';
 	$lang['strcascade'] = 'EN CASCADA';
 	$lang['strtablealtered'] = 'Tabla modificada.';
 	$lang['strtablealteredbad'] = 'Fall la modificacin  de la Tabla.';
-        $lang['strdataonly'] = 'Datos solamente';
+    $lang['strdataonly'] = 'Datos solamente';
 	$lang['strstructureonly'] = 'Solo la estructura';
 	$lang['strstructureanddata'] = 'Estructura y datos';
 	$lang['strtabbed'] = 'Tabulado';
 	$lang['strauto'] = 'Automtico';
-        $lang['strconfvacuumtable']  =  'Esta seguro que quiere limpiar "%s"?';
-        $lang['strestimatedrowcount']  =  'Estimacin de filas';
+    $lang['strconfvacuumtable']  =  'Esta seguro que quiere limpiar "%s"?';
+    $lang['strestimatedrowcount']  =  'Estimacin de filas';
 
-        // Users
+	// Columns
+	$lang['strcolprop'] = 'Propiedades de Columna';
+
+    // Users
 	$lang['struser'] = 'Usuario';
 	$lang['strusers'] = 'Usuarios';
 	$lang['strusername'] = 'Nombre de usuario';
@@ -225,7 +238,7 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strexpires'] = 'Expira';
 	$lang['strsessiondefaults'] = 'Valores predeterminados de la sesin.';
 	$lang['strnousers'] = 'No se encontraron usuarios.';
-        $lang['struserupdated'] = 'Usuario actualizado.';
+    $lang['struserupdated'] = 'Usuario actualizado.';
 	$lang['struserupdatedbad'] = 'Fall la actualizacin del usuario.';
 	$lang['strshowallusers'] = 'Mostrar Todos los Usuarios';
 	$lang['strcreateuser'] = 'Crear Usuario';
@@ -233,7 +246,7 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strusercreated'] = 'Usuario creado.';
 	$lang['strusercreatedbad'] = 'Fall al crear usuario.';
 	$lang['strconfdropuser'] = 'Est seguro que quiere eliminar el usuario "%s"?';
-        $lang['struserdropped'] = 'Usuario eliminado.';
+    $lang['struserdropped'] = 'Usuario eliminado.';
 	$lang['struserdroppedbad'] = 'Fall al eliminar el usuario.';
 	$lang['straccount'] = 'Cuenta';
 	$lang['strchangepassword'] = 'Cambiar Contrasea';
@@ -242,8 +255,8 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strpasswordshort'] = 'La contrasea es muy corta.';
 	$lang['strpasswordconfirm'] = 'Las contraseas no coinciden.';
 
-        // Groups
-        $lang['strgroup'] = 'Grupo';
+    // Groups
+    $lang['strgroup'] = 'Grupo';
 	$lang['strgroups']  =  'Grupos';
 	$lang['strnogroup'] = 'Grupo no encontrado.';
 	$lang['strnogroups'] = 'No se encontraron grupos.';
@@ -254,8 +267,10 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strgroupcreatedbad'] = 'Fall la creacin del grupo.';
 	$lang['strconfdropgroup'] = 'Est seguro que quiere eliminar el grupo "%s"?';
 	$lang['strgroupdropped'] = 'Grupo eliminado.';
-        $lang['strgroupdroppedbad'] = 'Fall la eliminacin del grupo.';
-        $lang['strmembers'] = 'Miembros';
+    $lang['strgroupdroppedbad'] = 'Fall la eliminacin del grupo.';
+    $lang['strmembers'] = 'Miembros';
+	$lang['strmemberof']  =  'Miembro de';
+	$lang['stradminmembers']  =  'Miembros Admin ';
 	$lang['straddmember'] = 'Agregar un miembro';
 	$lang['strmemberadded'] = 'Miembro agregado.';
 	$lang['strmemberaddedbad'] = 'Fall al intentar agregar nuevo miembro.';
@@ -264,7 +279,33 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strmemberdropped'] = 'Miembro eliminado.';
 	$lang['strmemberdroppedbad'] = 'Fall al intentar sacar un miembro.';
 
-	// Privilges
+	// Roles
+	$lang['strrole']  =  'Rol';
+	$lang['strroles']  =  'Roles';
+	$lang['strrolename']  =  'Nombre del Rol';
+	$lang['strshowallroles'] = 'Mostrar todas los rols';
+    $lang['strinheritsprivs']  =  'Hereda Privilegios?';
+	$lang['strcreaterole']  =  'Crear Rol';
+	$lang['strcancreaterole']  =  'Puede crear rols?';
+	$lang['strrolecreated']  =  'Rol creado.';
+	$lang['strrolecreatedbad']  =  'Fall al crear rol.';
+	$lang['stralterrole']  =  'Alterar role';
+$lang['strroleupdated']  =  'Role updated.';
+$lang['strroleupdatedbad']  =  'Role update failed.';
+$lang['strcatupdate']  =  'Modify Catalogs?';
+    $lang['strcanlogin']  =  'Puede loggearse?';
+$lang['strconnlimit']  =  'Connection limit';
+$lang['strdroprole']  =  'Drop role';
+    $lang['strmaxconnections']  =  'Mximo de conexiones';
+	$lang['strconfdroprole']  =  'Est seguro de que desea eliminar el rol "%s"?';
+    $lang['strroledropped']  =  'Usuario eliminado.';
+	$lang['strroledroppedbad']  =  'No puedo eliminar rol.';
+	$lang['strnoroles']  =  'No se encontraron los rols.';
+	$lang['strnolimit']  =  'Sin lmite';
+	$lang['strnever']  =  'Nunca';
+$lang['strroleneedsname']  =  'You must give a name for the role.';
+	
+	// Privileges
 	$lang['strprivilege'] = 'Privilegio';
 	$lang['strprivileges'] = 'Privilegios';
 	$lang['strnoprivileges'] = 'Este objeto tiene privilegios de usuario por defecto.';
@@ -301,11 +342,11 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strfull'] = 'Full';
 	$lang['strfreeze'] = 'Freeze';
 	$lang['strforce'] = 'Force';
-        $lang['strsignalsent']  =  'Seal enviada.';
-        $lang['strsignalsentbad']  =  'Fall el envo de la seal.';
-        $lang['strallobjects']  =  'Todos los objetos';
-        $lang['strdatabasealtered']  =  'Base de Datos alterada.';
-        $lang['strdatabasealteredbad']  =  'Fall al intentar alterar la Base de Datos.';
+    $lang['strsignalsent']  =  'Seal enviada.';
+    $lang['strsignalsentbad']  =  'Fall el envo de la seal.';
+    $lang['strallobjects']  =  'Todos los objetos';
+    $lang['strdatabasealtered']  =  'Base de Datos alterada.';
+    $lang['strdatabasealteredbad']  =  'Fall al intentar alterar la Base de Datos.';
 
 	// Views
 	$lang['strview'] = 'Vista';
@@ -317,7 +358,7 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strviewname'] = 'Nombre de Vista';
 	$lang['strviewneedsname'] = 'Debe darle un nombre a la vista.';
 	$lang['strviewneedsdef'] = 'Debe darle una definicin a su vista.';
-        $lang['strviewneedsfields'] = 'Seleccione por favor los campos que desea en su vista.';
+    $lang['strviewneedsfields'] = 'Seleccione por favor los campos que desea en su vista.';
 	$lang['strviewcreated'] = 'Vista creada.';
 	$lang['strviewcreatedbad'] = 'Fall al crear la vista.';
 	$lang['strconfdropview'] = 'Est seguro que quiere eliminar la vista "%s"?';
@@ -342,7 +383,7 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strmaxvalue'] = 'Valor Mximo';
 	$lang['strminvalue'] = 'Valor Mnimo';
 	$lang['strcachevalue'] = 'Valor de Cache';
-	$lang['strlogcount'] = 'Log Count';
+$lang['strlogcount'] = 'Log Count';
 	$lang['striscycled'] = 'Rotar?';
 	$lang['striscalled'] = 'Nombre?';
 	$lang['strsequenceneedsname'] = 'Debe darle un nombre a la secuencia.';
@@ -353,6 +394,15 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strsequencedroppedbad'] = 'Fall la eliminacin de la secuencia.';
 	$lang['strsequencereset'] = 'Secuencia reiniciada.';
 	$lang['strsequenceresetbad'] = 'Fall al intentar reiniciar la secuencia.'; 
+$lang['straltersequence']  =  'Alter sequence';
+$lang['strsequencealtered']  =  'Sequence altered.';
+$lang['strsequencealteredbad']  =  'Sequence alteration failed.';
+	$lang['strsetval']  =  'Fijar el valor';
+$lang['strsequencesetval']  =  'Sequence value set.';
+$lang['strsequencesetvalbad']  =  'Sequence value set failed.';
+$lang['strnextval']  =  'Increment Value';
+$lang['strsequencenextval']  =  'Sequence incremented.';
+$lang['strsequencenextvalbad']  =  'Sequence increment failed.';
 
 	// Indexes
 	$lang['strindex'] = 'ndice';
@@ -397,7 +447,7 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strruledroppedbad'] = 'Fall al eliminar la regla.';
 
 	// Constraints
-        $lang['strconstraint']  =  'Restriccin';
+    $lang['strconstraint']  =  'Restriccin';
 	$lang['strconstraints'] = 'Restricciones';
 	$lang['strshowallconstraints'] = 'Mostrar todas las restricciones';
 	$lang['strnoconstraints'] = 'No se encontraron restricciones.';
@@ -435,13 +485,12 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strshowallfunctions'] = 'Mostrar todas las funciones';
 	$lang['strnofunction'] = 'No se encontr la funcin.';
 	$lang['strnofunctions'] = 'No se encontraron funciones.';
-        $lang['strcreateplfunction']  =  'Crear funcin SQL/PL';
-        $lang['strcreateinternalfunction']  =  'Crear funcin interna';
-        $lang['strcreatecfunction']  =  'Crear funcin en C';
+    $lang['strcreateplfunction']  =  'Crear funcin SQL/PL';
+    $lang['strcreateinternalfunction']  =  'Crear funcin interna';
+    $lang['strcreatecfunction']  =  'Crear funcin en C';
 	$lang['strfunctionname'] = 'Nombre de la funcin';
 	$lang['strreturns'] = 'Devuelve';
-	$lang['strarguments'] = 'Argumentos';
-        $lang['strproglanguage'] = 'Lenguaje de programacin';
+    $lang['strproglanguage'] = 'Lenguaje de programacin';
 	$lang['strfunctionneedsname'] = 'Debe darle un nombre a la funcin.';
 	$lang['strfunctionneedsdef'] = 'Debe darle una definicin a la funcin.';
 	$lang['strfunctioncreated'] = 'Funcin creada.';
@@ -451,8 +500,22 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strfunctiondroppedbad'] = 'Fall al eliminar la funcin.';
 	$lang['strfunctionupdated'] = 'Funcin actualizada.';
 	$lang['strfunctionupdatedbad'] = 'Fall al actualizar la funcin.';
-        $lang['strobjectfile']  =  'Archivo de objeto';
-        $lang['strlinksymbol']  =  'Vinculo simblico';
+    $lang['strobjectfile']  =  'Archivo de objeto';
+    $lang['strlinksymbol']  =  'Vinculo simblico';
+    $lang['strarguments']  =  'Argumentos';
+    $lang['strargname']  =  'Nombre';
+    $lang['strargmode']  =  'Modo';
+    $lang['strargtype']  =  'Tipo';
+    $lang['strargadd']  =  'Agregar otro argumento';
+    $lang['strargremove']  =  'Eliminar este argumento';
+    $lang['strargnoargs']  =  'Esta funcin no tendr argumentos.';
+    $lang['strargenableargs']  =  'Habilitar argumentos pasados a esta funcin.';
+$lang['strargnorowabove']  =  'There needs to be a row above this row.';
+$lang['strargnorowbelow']  =  'There needs to be a row below this row.';
+    $lang['strargraise']  =  'Mover arriba.';
+    $lang['strarglower']  =  'Mover abajo.';
+    $lang['strargremoveconfirm']  =  'Esta seguro que quiere eliminar este argumento? Esto NO se puede deshacer.';
+
 
 	// Triggers
 	$lang['strtrigger'] = 'Disparador';
@@ -466,11 +529,17 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strtriggercreated'] = 'Disparador creado.';
 	$lang['strtriggercreatedbad'] = 'Fall la creacin del disparador.';
 	$lang['strconfdroptrigger'] = 'Est seguro que quiere eliminar el disparador "%s" en "%s"?';
+$lang['strconfenabletrigger']  =  'Are you sure you want to enable the trigger "%s" on "%s"?';
+$lang['strconfdisabletrigger']  =  'Are you sure you want to disable the trigger "%s" on "%s"?';
 	$lang['strtriggerdropped'] = 'Disparador eliminado.';
 	$lang['strtriggerdroppedbad'] = 'Fall al eliminar el disparador.';
-        $lang['strtriggeraltered'] = 'Disparador modificado.';
-        $lang['strtriggeralteredbad'] = 'Fall la modificacin del disparador.';
-        $lang['strforeach']  =  'Para cada uno';
+$lang['strtriggerenabled']  =  'Trigger enabled.';
+$lang['strtriggerenabledbad']  =  'Trigger enable failed.';
+$lang['strtriggerdisabled']  =  'Trigger disabled.';
+$lang['strtriggerdisabledbad']  =  'Trigger disable failed.';
+    $lang['strtriggeraltered'] = 'Disparador modificado.';
+    $lang['strtriggeralteredbad'] = 'Fall la modificacin del disparador.';
+    $lang['strforeach']  =  'Para cada uno';
 
 	// Types
 	$lang['strtype'] = 'Tipo de dato';
@@ -479,9 +548,9 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strnotype'] = 'No se encontr el tipo.';
 	$lang['strnotypes'] = 'No se encontraron tipos.';
 	$lang['strcreatetype'] = 'Crear Tipo';
-        $lang['strcreatecomptype']  =  'Crear tipo compuesto';
-        $lang['strtypeneedsfield']  =  'Debe especificar al menos un campo.';
-        $lang['strtypeneedscols']  =  'Tipos compuestos requieren de un nmero valido de columnas.';	
+    $lang['strcreatecomptype']  =  'Crear tipo compuesto';
+    $lang['strtypeneedsfield']  =  'Debe especificar al menos un campo.';
+    $lang['strtypeneedscols']  =  'Tipos compuestos requieren de un nmero valido de columnas.';	
 	$lang['strtypename'] = 'Nombre del tipo';
 	$lang['strinputfn'] = 'Funcin de entrada';
 	$lang['stroutputfn'] = 'Funcin de salida';
@@ -490,8 +559,8 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strelement'] = 'Elemento';
 	$lang['strdelimiter'] = 'Delimitador';
 	$lang['strstorage'] = 'Almacenamiento';
-        $lang['strfield']  =  'Campo';
-        $lang['strnumfields']  =  'Cantidad de campos';
+    $lang['strfield']  =  'Campo';
+    $lang['strnumfields']  =  'Cantidad de campos';
 	$lang['strtypeneedsname'] = 'Debe especificar un nombre para el tipo.';
 	$lang['strtypeneedslen'] = 'Debe especificar una longitud para el tipo.';
 	$lang['strtypecreated'] = 'Tipo creado';
@@ -499,10 +568,10 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strconfdroptype'] = 'Est seguro que quiere eliminar el tipo "%s"?';
 	$lang['strtypedropped'] = 'Tipo eliminado.';
 	$lang['strtypedroppedbad'] = 'Fall al eliminar el tipo.';
-        $lang['strflavor']  =  'Tipo';
-        $lang['strbasetype']  =  'Base';
-        $lang['strcompositetype']  =  'Compuesto';
-        $lang['strpseudotype']  =  'Pseudo';
+    $lang['strflavor']  =  'Tipo';
+    $lang['strbasetype']  =  'Base';
+    $lang['strcompositetype']  =  'Compuesto';
+    $lang['strpseudotype']  =  'Pseudo';
 
 	// Schemas
 	$lang['strschema'] = 'Esquema';
@@ -520,7 +589,7 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strschemadroppedbad'] = 'Fall al eliminar el esquema.';
 	$lang['strschemaaltered'] = 'Esquema modificado.';
 	$lang['strschemaalteredbad'] = 'Modificacin del esquema fall.';
-        $lang['strsearchpath']  =  'Orden de busqueda en esquemas';
+    $lang['strsearchpath']  =  'Orden de busqueda en esquemas';
 
 	// Reports
 	$lang['strreport'] = 'Reporte';
@@ -550,7 +619,7 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strdomainalteredbad'] = 'Fall al intentar modificar el dominio.';
 
 	// Operators
-        $lang['stroperator'] = 'Operador';
+    $lang['stroperator'] = 'Operador';
 	$lang['stroperators'] = 'Operadores';
 	$lang['strshowalloperators'] = 'Mostrar todos los operadores';
 	$lang['strnooperator'] = 'No se encontr el operador.';
@@ -602,9 +671,32 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strchildtables'] = 'Child tables';
 
 	// Aggregates
+$lang['straggregate']  =  'Aggregate';
 	$lang['straggregates'] = 'Agregadas';
 	$lang['strnoaggregates'] = 'No se encontraron agregadas.';
 	$lang['stralltypes'] = '(Todos los tipos)';
+$lang['straggrtransfn']  =  'Transition function';
+	$lang['strcreateaggregate']  =  'Crear aggregada';
+$lang['straggrbasetype']  =  'Input data type';
+$lang['straggrsfunc']  =  'State transition function';
+$lang['straggrstype']  =  'State data type';
+$lang['straggrffunc']  =  'Final function';
+$lang['straggrinitcond']  =  'Initial condition';
+$lang['straggrsortop']  =  'Sort operator';
+	$lang['strdropaggregate']  =  'Eliminar aggregada';
+$lang['strconfdropaggregate']  =  'Are you sure you want to drop the aggregate "%s"?';
+$lang['straggregatedropped']  =  'Aggregate dropped.';
+$lang['straggregatedroppedbad']  =  'Aggregate drop failed.';
+$lang['stralteraggregate']  =  'Alter aggregate';
+$lang['straggraltered']  =  'Aggregate altered.';
+$lang['straggralteredbad']  =  'Aggregate alteration failed.';
+$lang['straggrneedsname']  =  'You must specify a name for the aggregate';
+$lang['straggrneedsbasetype']  =  'You must specify the input data type for the aggregate';
+$lang['straggrneedssfunc']  =  'You must specify the name of the state transition function for the aggregate';
+$lang['straggrneedsstype']  =  'You must specify the data type for the aggregate\'s state value';
+$lang['straggrcreated']  =  'Aggregate created.';
+$lang['straggrcreatedbad']  =  'Aggregate creation failed.';
+	$lang['straggrshowall']  =  'Mostrar todas las aggregadas';
 
 	// Operator Classes
 	$lang['stropclasses'] = 'Clases de operadores';
@@ -629,21 +721,21 @@ $lang['strnull']  =  'NULL (The word)';
 	$lang['strrows2'] = 'Rows';
 
 	// Tablespaces
-        $lang['strtablespace']  =  'Tablespace';
-        $lang['strtablespaces']  =  'Tablespaces';
-        $lang['strshowalltablespaces']  =  'Mostrar todos los tablespaces';
-        $lang['strnotablespaces']  =  'No se encontraron tablespaces.';
-        $lang['strcreatetablespace']  =  'Crear tablespace';
-        $lang['strlocation']  =  'Ubicacin';
-        $lang['strtablespaceneedsname']  =  'Debe darle un nombre al tablespace.';
-        $lang['strtablespaceneedsloc']  =  'Debe dar un directorio en donde crear el tablespace.';
-        $lang['strtablespacecreated']  =  'Tablespace creado.';
-        $lang['strtablespacecreatedbad']  =  'Fall la creacin del tablespace.';
-        $lang['strconfdroptablespace']  =  'Esta seguro que quiere eliminar el tablespace "%s"?';
-        $lang['strtablespacedropped']  =  'Tablespace eliminado.';
-        $lang['strtablespacedroppedbad']  =  'Fall al intenta eliminar el tablespace.';
-        $lang['strtablespacealtered']  =  'Tablespace modificado.';
-        $lang['strtablespacealteredbad']  =  'Fall la modificacin del Tablespace.';
+    $lang['strtablespace']  =  'Tablespace';
+    $lang['strtablespaces']  =  'Tablespaces';
+    $lang['strshowalltablespaces']  =  'Mostrar todos los tablespaces';
+    $lang['strnotablespaces']  =  'No se encontraron tablespaces.';
+    $lang['strcreatetablespace']  =  'Crear tablespace';
+    $lang['strlocation']  =  'Ubicacin';
+    $lang['strtablespaceneedsname']  =  'Debe darle un nombre al tablespace.';
+    $lang['strtablespaceneedsloc']  =  'Debe dar un directorio en donde crear el tablespace.';
+    $lang['strtablespacecreated']  =  'Tablespace creado.';
+    $lang['strtablespacecreatedbad']  =  'Fall la creacin del tablespace.';
+    $lang['strconfdroptablespace']  =  'Esta seguro que quiere eliminar el tablespace "%s"?';
+    $lang['strtablespacedropped']  =  'Tablespace eliminado.';
+    $lang['strtablespacedroppedbad']  =  'Fall al intenta eliminar el tablespace.';
+    $lang['strtablespacealtered']  =  'Tablespace modificado.';
+    $lang['strtablespacealteredbad']  =  'Fall la modificacin del Tablespace.';
 
 	// Slony clusters
 $lang['strcluster']  =  'Cluster';
@@ -658,9 +750,9 @@ $lang['strclusterneedsname']  =  'You must give a name for the cluster.';
 $lang['strclusterneedsnodeid']  =  'You must give an ID for the local node.';
 	
 	// Slony nodes
-$lang['strnodes']  =  'Nodes';
-$lang['strnonodes']  =  'No nodes found.';
-$lang['strcreatenode']  =  'Create node';
+	$lang['strnodes']  =  'Nodos';
+	$lang['strnonodes'] = 'No se encontraron los nodos.';
+    $lang['strcreatenode']  =  'Crear nodo';
 $lang['strid']  =  'ID';
 $lang['stractive']  =  'Active';
 $lang['strnodecreated']  =  'Node created.';
@@ -668,14 +760,19 @@ $lang['strnodecreatedbad']  =  'Node creation failed.';
 $lang['strconfdropnode']  =  'Are you sure you want to drop node "%s"?';
 $lang['strnodedropped']  =  'Node dropped.';
 $lang['strnodedroppedbad']  =  'Node drop failed';
-$lang['strfailover']  =  'Failover';
+$lang['strfailover']  =  'Filtro';
 $lang['strnodefailedover']  =  'Node failed over.';
 $lang['strnodefailedoverbad']  =  'Node fail over fail.';
+$lang['strstatus']  =  'Status';	
+$lang['strhealthy']  =  'Healthy';
+$lang['stroutofsync']  =  'Out of Sync';
+$lang['strunknown']  =  'Unknown';	
+
 	
 	// Slony paths	
-$lang['strpaths']  =  'Paths';
-$lang['strnopaths']  =  'No paths found.';
-$lang['strcreatepath']  =  'Create path';
+    $lang['strpaths']  =  'Rutas';
+	$lang['strnopaths'] = 'No se encontraron rutas.';
+    $lang['strcreatepath']  =  'Crear ruta';
 $lang['strnodename']  =  'Node name';
 $lang['strnodeid']  =  'Node ID';
 $lang['strconninfo']  =  'Connection string';
@@ -699,23 +796,23 @@ $lang['strlistendropped']  =  'Listen dropped.';
 $lang['strlistendroppedbad']  =  'Listen drop failed.';
 
 	// Slony replication sets
-$lang['strrepsets']  =  'Replication sets';
-$lang['strnorepsets']  =  'No replication sets found.';
-$lang['strcreaterepset']  =  'Create replication set';
+	$lang['strrepsets']  =  'Conjuntos de Replicacin';
+	$lang['strnorepsets'] = 'No se encontraron conjuntos de Replicacin.';
+	$lang['strcreaterepset']  =  'Crear un Conjunto de Replicacin';
 $lang['strrepsetcreated']  =  'Replication set created.';
 $lang['strrepsetcreatedbad']  =  'Replication set creation failed.';
 $lang['strconfdroprepset']  =  'Are you sure you want to drop replication set "%s"?';
 $lang['strrepsetdropped']  =  'Replication set dropped.';
 $lang['strrepsetdroppedbad']  =  'Replication set drop failed.';
-$lang['strmerge']  =  'Merge';
+	$lang['strmerge']  =  'Unir';
 $lang['strmergeinto']  =  'Merge Into';
 $lang['strrepsetmerged']  =  'Replication sets merged.';
 $lang['strrepsetmergedbad']  =  'Replication sets merge failed.';
-$lang['strmove']  =  'Move';
-$lang['strneworigin']  =  'New Origin';
+	$lang['strmove']  =  'Mover';
+	$lang['strneworigin']  =  'Origen Nuevo';
 $lang['strrepsetmoved']  =  'Replication set moved.';
 $lang['strrepsetmovedbad']  =  'Replication set move failed.';
-$lang['strnewrepset']  =  'New replication set';
+	$lang['strnewrepset']  =  'Nuevo Conjunto de Replicacin';
 $lang['strlock']  =  'Lock';
 $lang['strlocked']  =  'Locked';
 $lang['strunlock']  =  'Unlock';
@@ -751,18 +848,41 @@ $lang['strsequenceremovedfromrepset']  =  'Sequence removed from replication set
 $lang['strsequenceremovedfromrepsetbad']  =  'Failed to remove sequence from replication set.';
 
 	// Slony subscriptions
-        $lang['strsubscriptions']  =  'Subscripciones';
-        $lang['strnosubscriptions']  =  'No se encontraron subscripciones.';
+    $lang['strsubscriptions']  =  'Subscripciones';
+    $lang['strnosubscriptions']  =  'No se encontraron subscripciones.';
 
 	// Miscellaneous
 	$lang['strtopbar'] = '%s corriendo en %s:%s -- Usted est logueado con usuario "%s", %s';
 	$lang['strtimefmt'] = 'd/m/Y, G:i:s';
 	$lang['strhelp'] = 'Ayuda';
-        $lang['strhelpicon']  =  '?';
-        $lang['strlogintitle']  =  'Loguearse a %s';
-        $lang['strlogoutmsg']  =  'Saliendo de %s';
-        $lang['strloading']  =  'Cargando...';
-        $lang['strerrorloading']  =  'Error Cargando';
-        $lang['strclicktoreload']  =  'Click para recargar';
+    $lang['strhelpicon']  =  '?';
+    $lang['strlogintitle']  =  'Loguearse a %s';
+    $lang['strlogoutmsg']  =  'Saliendo de %s';
+    $lang['strloading']  =  'Cargando...';
+    $lang['strerrorloading']  =  'Error Cargando';
+    $lang['strclicktoreload']  =  'Click para recargar';
 
+	// Autovacuum
+	$lang['strautovacuum']  =  'Autovacuum'; 
+$lang['strturnedon']  =  'Turned On'; 
+$lang['strturnedoff']  =  'Turned Off'; 
+    $lang['strenabled']  =  'Habilitado'; 
+    $lang['strvacuumbasethreshold']  =  'Umbral de Vacuum'; 
+$lang['strvacuumscalefactor']  =  'Vacuum Scale Factor';  
+$lang['stranalybasethreshold']  =  'Analyze Base Threshold';  
+$lang['stranalyzescalefactor']  =  'Analyze Scale Factor'; 
+	$lang['strvacuumcostdelay']  =  'Tiempo de descanso de vacuum'; 
+$lang['strvacuumcostlimit']  =  'Vacuum Cost Limit';  
+
+    // Table-level Locks
+    $lang['strlocks']  =  'Bloqueos';
+    $lang['strtransaction']  =  'ID de transaccin';
+    $lang['strprocessid']  =  'ID de proceso';
+    $lang['strmode']  =  'Modo de bloqueo';
+    $lang['strislockheld'] = 'Se mantiene el bloqueo?';
+
+	// Prepared transactions
+    $lang['strpreparedxacts']  =  'Transacciones preparadas';
+    $lang['strxactid']  =  'ID de Transaccin';
+    $lang['strgid']  =  'ID Global';
 ?>
