@@ -3,14 +3,13 @@
 	/**
 	 * List tables in a database
 	 *
-	 * $Id: tblproperties.php,v 1.67 2005/10/18 03:45:16 chriskl Exp $
+	 * $Id: tblproperties.php,v 1.72.2.1 2007/05/28 17:21:56 ioguix Exp $
 	 */
 
 	// Include application functions
 	include_once('./libraries/lib.inc.php');
 
 	$action = (isset($_REQUEST['action'])) ? $_REQUEST['action'] : '';
-	$PHP_SELF = $_SERVER['PHP_SELF'];
 
 	/** 
 	 * Function to save after altering a table
@@ -132,7 +131,7 @@
 		echo "<tr><th class=\"data\">{$lang['strformat']}</th><th class=\"data\" colspan=\"2\">{$lang['stroptions']}</th></tr>\n";
 		// Data only
 		echo "<tr><th class=\"data left\" rowspan=\"", ($hasID) ? 2 : 1, "\">";
-		echo "<input type=\"radio\" name=\"what\" value=\"dataonly\" checked=\"checked\" />{$lang['strdataonly']}</th>\n";
+		echo "<input type=\"radio\" id=\"what1\" name=\"what\" value=\"dataonly\" checked=\"checked\" /><label for=\"what1\">{$lang['strdataonly']}</label></th>\n";
 		echo "<td>{$lang['strformat']}</td>\n";
 		echo "<td><select name=\"d_format\">\n";
 		echo "<option value=\"copy\">COPY</option>\n";
@@ -143,28 +142,28 @@
 		echo "<option value=\"xml\">XML</option>\n";
 		echo "</select>\n</td>\n</tr>\n";
 		if ($hasID) {
-			echo "<tr><td>{$lang['stroids']}</td><td><input type=\"checkbox\" name=\"d_oids\" /></td>\n</tr>\n";
+			echo "<tr><td><label for=\"d_oids\">{$lang['stroids']}</td><td><input type=\"checkbox\" id=\"d_oids\" name=\"d_oids\" /></td>\n</tr>\n";
 		}
 		// Structure only
-		echo "<tr><th class=\"data left\"><input type=\"radio\" name=\"what\" value=\"structureonly\" />{$lang['strstructureonly']}</th>\n";
-		echo "<td>{$lang['strdrop']}</td><td><input type=\"checkbox\" name=\"s_clean\" /></td>\n</tr>\n";
+		echo "<tr><th class=\"data left\"><input type=\"radio\" id=\"what2\" name=\"what\" value=\"structureonly\" /><label for=\"what2\">{$lang['strstructureonly']}</label></th>\n";
+		echo "<td><label for=\"s_clean\">{$lang['strdrop']}</label></td><td><input type=\"checkbox\" id=\"s_clean\" name=\"s_clean\" /></td>\n</tr>\n";
 		// Structure and data
 		echo "<tr><th class=\"data left\" rowspan=\"", ($hasID) ? 3 : 2, "\">";
-		echo "<input type=\"radio\" name=\"what\" value=\"structureanddata\" />{$lang['strstructureanddata']}</th>\n";
+		echo "<input type=\"radio\" id=\"what3\" name=\"what\" value=\"structureanddata\" /><label for=\"what3\">{$lang['strstructureanddata']}</label></th>\n";
 		echo "<td>{$lang['strformat']}</td>\n";
 		echo "<td><select name=\"sd_format\">\n";
 		echo "<option value=\"copy\">COPY</option>\n";
 		echo "<option value=\"sql\">SQL</option>\n";
 		echo "</select>\n</td>\n</tr>\n";
-		echo "<tr><td>{$lang['strdrop']}</td><td><input type=\"checkbox\" name=\"sd_clean\" /></td>\n</tr>\n";
+		echo "<tr><td><label for=\"sd_clean\">{$lang['strdrop']}</label></td><td><input type=\"checkbox\" id=\"sd_clean\" name=\"sd_clean\" /></td>\n</tr>\n";
 		if ($hasID) {
-			echo "<tr><td>{$lang['stroids']}</td><td><input type=\"checkbox\" name=\"sd_oids\" /></td>\n</tr>\n";
+			echo "<tr><td><label for=\"sd_oids\">{$lang['stroids']}</label></td><td><input type=\"checkbox\" id=\"sd_oids\" name=\"sd_oids\" /></td>\n</tr>\n";
 		}
 		echo "</table>\n";
 		
 		echo "<h3>{$lang['stroptions']}</h3>\n";
-		echo "<p><input type=\"radio\" name=\"output\" value=\"show\" checked=\"checked\" />{$lang['strshow']}\n";
-		echo "<br/><input type=\"radio\" name=\"output\" value=\"download\" />{$lang['strdownload']}</p>\n";
+		echo "<p><input type=\"radio\" id=\"output1\" name=\"output\" value=\"show\" checked=\"checked\" /><label for=\"output1\">{$lang['strshow']}</label>\n";
+		echo "<br/><input type=\"radio\" id=\"output2\" name=\"output\" value=\"download\" /><label for=\"output2\">{$lang['strdownload']}</label></p>\n";
 
 		echo "<p><input type=\"hidden\" name=\"action\" value=\"export\" />\n";
 		echo $misc->form;
@@ -222,7 +221,7 @@
 	 * Displays a screen where they can add a column
 	 */
 	function doAddColumn($msg = '') {
-		global $data, $misc;
+		global $data, $misc, $_reload_browser;
 		global $PHP_SELF, $lang;
 
 		if (!isset($_REQUEST['stage'])) $_REQUEST['stage'] = 1;
@@ -241,15 +240,16 @@
 
 				// Fetch all available types
 				$types = $data->getTypes(true, false, true);
+				$types_for_js = array();
 
 				$misc->printTrail('table');
 				$misc->printTitle($lang['straddcolumn'], 'pg.column.add');
 				$misc->printMsg($msg);
-
+				echo "<script src=\"tables.js\" type=\"text/javascript\"></script>";
 				echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
 
 				// Output table header
-				echo "<table>\n<tr>";
+				echo "<table>\n";
 				echo "<tr><th class=\"data required\">{$lang['strcolumn']}</th><th colspan=\"2\" class=\"data required\">{$lang['strtype']}</th>";
 				echo "<th class=\"data\">{$lang['strlength']}</th>";
 				if ($data->hasAlterColumnType()) echo "<th class=\"data\">{$lang['strnotnull']}</th><th class=\"data\">{$lang['strdefault']}</th>";
@@ -257,10 +257,11 @@
 
 				echo "<tr><td><input name=\"field\" size=\"16\" maxlength=\"{$data->_maxNameLen}\" value=\"",
 					htmlspecialchars($_POST['field']), "\" /></td>";
-				echo "<td><select name=\"type\">\n";				
+				echo "<td><select name=\"type\" id=\"type\" onchange=\"checkLengths(document.getElementById('type').value,'');\">\n";				
 				// Output any "magic" types.  This came in with the alter column type so we'll check that
 				if ($data->hasAlterColumnType()) {
 					foreach ($data->extraTypes as $v) {
+						$types_for_js[strtolower($v)] = 1;
 						echo "<option value=\"", htmlspecialchars($v), "\"",
 						($v == $_POST['type']) ? ' selected="selected"' : '', ">",
 							$misc->printVal($v), "</option>\n";
@@ -268,6 +269,7 @@
 				}
 				while (!$types->EOF) {
 					$typname = $types->f['typname'];
+					$types_for_js[$typname] = 1;
 					echo "<option value=\"", htmlspecialchars($typname), "\"", ($typname == $_POST['type']) ? ' selected="selected"' : '', ">",
 						$misc->printVal($typname), "</option>\n";
 					$types->moveNext();
@@ -278,9 +280,15 @@
 				echo "<td><select name=\"array\">\n";
 				echo "<option value=\"\"", ($_POST['array'] == '') ? ' selected="selected"' : '', "></option>\n";
 				echo "<option value=\"[]\"", ($_POST['array'] == '[]') ? ' selected="selected"' : '', ">[ ]</option>\n";
-				echo "</select></td>\n";
+				echo "</select>";
+				$predefined_size_types = array_intersect($data->predefined_size_types,array_keys($types_for_js));
+				$escaped_predef_types = array(); // the JS escaped array elements
+				foreach($predefined_size_types as $value) {
+					$escaped_predef_types[] = "'{$value}'";
+				}
+				echo "\t</td>\n";
 
-				echo "<td><input name=\"length\" size=\"8\" value=\"",
+				echo "<td><input name=\"length\" id=\"lengths\" size=\"8\" value=\"",
 					htmlspecialchars($_POST['length']), "\" /></td>";
 				// Support for adding column with not null and default
 				if ($data->hasAlterColumnType()) {					
@@ -302,7 +310,7 @@
 				echo "<p><input type=\"submit\" value=\"{$lang['stradd']}\" />\n";
 				echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" /></p>\n";
 				echo "</form>\n";
-
+				echo "<script type=\"text/javascript\">predefined_lengths = new Array(". implode(",",$escaped_predef_types) .");checkLengths(document.getElementById('type').value,'');</script>\n";
 				break;
 			case 2:
 				global $data, $lang;
@@ -317,8 +325,10 @@
 				$status = $data->addColumn($_POST['table'], $_POST['field'],
 							   $_POST['type'], $_POST['array'] != '', $_POST['length'], isset($_POST['notnull']),
 							   $_POST['default'], $_POST['comment']);
-				if ($status == 0)
+				if ($status == 0) {
+					$_reload_browser = true;
 					doDefault($lang['strcolumnadded']);
+				}
 				else {
 					$_REQUEST['stage'] = 1;
 					doAddColumn($lang['strcolumnaddedbad']);
@@ -334,7 +344,7 @@
 	 * Displays a screen where they can alter a column
 	 */
 	function doProperties($msg = '') {
-		global $data, $misc;
+		global $data, $misc, $_reload_browser;
 		global $PHP_SELF, $lang;
 
 		if (!isset($_REQUEST['stage'])) $_REQUEST['stage'] = 1;
@@ -346,11 +356,12 @@
 				$misc->printTrail('column');
 				$misc->printTitle($lang['straltercolumn'], 'pg.column.alter'); 
 				$misc->printMsg($msg);
+				echo "<script src=\"tables.js\" type=\"text/javascript\"></script>";
 
 				echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
 
 				// Output table header
-				echo "<table>\n<tr>";
+				echo "<table>\n";
 				echo "<tr><th class=\"data required\">{$lang['strname']}</th>";
 				if ($data->hasAlterColumnType()) {
 					echo "<th class=\"data required\" colspan=\"2\">{$lang['strtype']}</th>";
@@ -399,16 +410,19 @@
 				if ($data->hasAlterColumnType()) {
 					// Fetch all available types
 					$types = $data->getTypes(true, false, true);
+					$types_for_js = array();
 					
-					echo "<td><select name=\"type\">\n";				
+					echo "<td><select name=\"type\" id=\"type\" onchange=\"checkLengths(document.getElementById('type').value,'');\">\n";
 					// Output any "magic" types.  This came in with Alter Column Type so we don't need to check that
 					foreach ($data->extraTypes as $v) {
+						$types_for_js[strtolower($v)] = 1;
 						echo "<option value=\"", htmlspecialchars($v), "\"",
 						($v == $_REQUEST['type']) ? ' selected="selected"' : '', ">",
 							$misc->printVal($v), "</option>\n";
 					}
 					while (!$types->EOF) {
 						$typname = $types->f['typname'];
+						$types_for_js[$typname] = 1;
 						echo "<option value=\"", htmlspecialchars($typname), "\"", ($typname == $_REQUEST['type']) ? ' selected="selected"' : '', ">",
 							$misc->printVal($typname), "</option>\n";
 						$types->moveNext();
@@ -419,9 +433,15 @@
 					echo "<td><select name=\"array\">\n";
 					echo "<option value=\"\"", ($_REQUEST['array'] == '') ? ' selected="selected"' : '', "></option>\n";
 					echo "<option value=\"[]\"", ($_REQUEST['array'] == '[]') ? ' selected="selected"' : '', ">[ ]</option>\n";
-					echo "</select></td>\n";
-	
-					echo "<td><input name=\"length\" size=\"8\" value=\"",
+					echo "</select>";
+					$predefined_size_types = array_intersect($data->predefined_size_types,array_keys($types_for_js));
+					$escaped_predef_types = array(); // the JS escaped array elements
+					foreach($predefined_size_types as $value) {
+						$escaped_predef_types[] = "'{$value}'";
+					}
+					echo "\t</td>\n";
+
+					echo "<td><input name=\"length\" id=\"lengths\" size=\"8\" value=\"",	
 						htmlspecialchars($_REQUEST['length']), "\" /></td>";
 				} else {
 					// Otherwise draw the read-only type name
@@ -452,6 +472,7 @@
 				echo "<input type=\"submit\" value=\"{$lang['stralter']}\" />\n";
 				echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" /></p>\n";
 				echo "</form>\n";
+				echo "<script type=\"text/javascript\">predefined_lengths = new Array(". implode(",",$escaped_predef_types) .");checkLengths(document.getElementById('type').value,'');</script>\n";
 								
 				break;
 			case 2:
@@ -469,8 +490,13 @@
 							     $_REQUEST['default'], $_REQUEST['olddefault'],
 							     $_REQUEST['type'], $_REQUEST['length'], $_REQUEST['array'], $_REQUEST['oldtype'],
 							     $_REQUEST['comment']);
-				if ($status == 0)
+				if ($status == 0) {
+					if ($_REQUEST['column'] != $_REQUEST['field']) {
+						$_reload_browser = true;
+						$_REQUEST['column'] = $_REQUEST['field'];
+					}
 					doDefault($lang['strcolumnaltered']);
+				}
 				else {
 					$_REQUEST['stage'] = 1;
 					doProperties($lang['strcolumnalteredbad']);
@@ -486,7 +512,7 @@
 	 * Show confirmation of drop column and perform actual drop
 	 */
 	function doDrop($confirm) {
-		global $data, $database, $misc;
+		global $data, $database, $misc, $_reload_browser;
 		global $PHP_SELF, $lang;
 
 		if ($confirm) {
@@ -504,7 +530,7 @@
 			echo $misc->form;
 			// Show cascade drop option if supportd
 			if ($data->hasDropBehavior()) {
-				echo "<p><input type=\"checkbox\" name=\"cascade\"> {$lang['strcascade']}</p>\n";
+				echo "<p><input type=\"checkbox\" id=\"cascade\" name=\"cascade\"> <label for=\"cascade\">{$lang['strcascade']}</label></p>\n";
 			}
 			echo "<input type=\"submit\" name=\"drop\" value=\"{$lang['strdrop']}\" />\n";
 			echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" />\n";
@@ -512,14 +538,56 @@
 		}
 		else {
 			$status = $data->dropColumn($_POST['table'], $_POST['column'], isset($_POST['cascade']));
-			if ($status == 0)
+			if ($status == 0) {
+				$_reload_browser = true;
 				doDefault($lang['strcolumndropped']);
+			}
 			else
 				doDefault($lang['strcolumndroppedbad']);
 		}
 		
 	}
 
+	function doTree() {
+		global $misc, $data;
+
+		$columns = $data->getTableAttributes($_REQUEST['table']);
+		$reqvars = $misc->getRequestVars('column');
+
+		$attrs = array (
+			'text'   => field('attname'),
+			'action' => url('colproperties.php',
+							$reqvars,
+							array(
+								'table'		=> $_REQUEST['table'],
+								'column'	=> field('attname')
+							)
+						),
+			'icon'   => 'Column',
+			'iconAction' => url('display.php',
+								$reqvars,
+								array(
+									'table'		=> $_REQUEST['table'],
+									'column'	=> field('attname'),
+									'query'		=> prepareSQL(
+														"SELECT %column%, count(*) AS \"count\" FROM %table% GROUP BY %column% ORDER BY %column%", 
+														array (
+															'%column%' => field('attname'),
+															'%table%' => $_REQUEST['table']
+														)
+													)
+								)
+							),
+			'toolTip'=> field('comment')
+		);
+
+		$misc->printTreeXML($columns, $attrs);
+
+		exit;
+	}
+
+	if ($action == 'tree') doTree();
+
 	/**
 	 * Show default list of columns in the table
 	 */
@@ -539,7 +607,7 @@
 		// Get table
 		$tdata = $data->getTable($_REQUEST['table']);
 		// Get columns
-		$attrs = $data->getTableAttributes($_REQUEST['table']);		
+		$attrs = $data->getTableAttributes($_REQUEST['table']);
 
 		// Show comment if any
 		if ($tdata->f['relcomment'] !== null)
@@ -574,6 +642,11 @@
 		);
 		
 		$actions = array(
+			'properties' => array(
+				'title' => $lang['strproperties'],
+				'url'   => "colproperties.php?subject=column&amp;{$misc->href}&amp;table=".urlencode($_REQUEST['table'])."&amp;",
+				'vars'  => array('column' => 'attname'),
+			),
 			'alter' => array(
 				'title' => $lang['stralter'],
 				'url'   => "{$PHP_SELF}?action=properties&amp;{$misc->href}&amp;table=".urlencode($_REQUEST['table'])."&amp;",
@@ -593,7 +666,7 @@
 		echo "<br />\n";
 
 		echo "<ul>\n";
-		$return_url = urlencode("tblproperties.php?{$misc->href}&table={$_REQUEST['table']}");
+		$return_url = urlencode("tblproperties.php?{$misc->href}&amp;table={$_REQUEST['table']}");
 		echo "\t<li><a href=\"display.php?{$misc->href}&amp;table=", urlencode($_REQUEST['table']), "&amp;subject=table&amp;return_url={$return_url}&amp;return_desc=",
 			urlencode($lang['strback']), "\">{$lang['strbrowse']}</a></li>\n";
 		echo "\t<li><a href=\"tables.php?action=confselectrows&amp;{$misc->href}&amp;table=", urlencode($_REQUEST['table']),"\">{$lang['strselect']}</a></li>\n";
