@@ -3,7 +3,7 @@
 	/**
 	 * Manage types in a database
 	 *
-	 * $Id: types.php,v 1.28 2005/10/18 03:45:16 chriskl Exp $
+	 * $Id: types.php,v 1.31.2.1 2007/05/28 17:21:56 ioguix Exp $
 	 */
 
 	// Include application functions
@@ -11,7 +11,6 @@
 	
 	$action = (isset($_REQUEST['action'])) ? $_REQUEST['action'] : '';
 	if (!isset($msg)) $msg = '';
-	$PHP_SELF = $_SERVER['PHP_SELF'];
 
 	/**
 	 * Show read only properties for a type
@@ -100,7 +99,7 @@
 			echo $misc->form;
 			// Show cascade drop option if supportd
 			if ($data->hasDropBehavior()) {
-				echo "<p><input type=\"checkbox\" name=\"cascade\" /> {$lang['strcascade']}</p>\n";
+				echo "<p><input type=\"checkbox\" id=\"cascade\" name=\"cascade\" /> <label for=\"cascade\">{$lang['strcascade']}</label></p>\n";
 			}
 			echo "<input type=\"submit\" name=\"drop\" value=\"{$lang['strdrop']}\" />\n";
 			echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" />\n";
@@ -173,7 +172,7 @@
 
 				$types = $data->getTypes(true, false, true);
 
-				$misc->printTrail('type');
+				$misc->printTrail('schema');
 				$misc->printTitle($lang['strcreatecomptype'], 'pg.type.create');
 				$misc->printMsg($msg);
 
@@ -332,8 +331,8 @@
 		echo "<tr><th class=\"data left\">{$lang['strdelimiter']}</th>\n";
 		echo "<td class=\"data1\"><input name=\"typdelim\" size=\"1\" maxlength=\"1\" value=\"",
 			htmlspecialchars($_POST['typdelim']), "\" /></td></tr>";
-		echo "<tr><th class=\"data left\">{$lang['strpassbyval']}</th>\n";
-		echo "<td class=\"data1\"><input type=\"checkbox\" name=\"typbyval\"", 
+		echo "<tr><th class=\"data left\"><label for=\"typbyval\">{$lang['strpassbyval']}</label></th>\n";
+		echo "<td class=\"data1\"><input type=\"checkbox\" id=\"typbyval\" name=\"typbyval\"", 
 			isset($_POST['typbyval']) ? ' checked="checked"' : '', " /></td></tr>";
 		echo "<tr><th class=\"data left\">{$lang['stralignment']}</th>\n";
 		echo "<td class=\"data1\"><select name=\"typalign\">";
@@ -470,7 +469,7 @@
 		
 		$attrs = array(
 			'text'   => field('typname'),
-			'icon'   => 'types',
+			'icon'   => 'Type',
 			'toolTip'=> field('typcomment'),
 			'action' => url('types.php',
 							$reqvars,
