@@ -3,7 +3,7 @@
 	/**
 	 * Manage views in a database
 	 *
-	 * $Id: views.php,v 1.54 2005/10/18 03:45:16 chriskl Exp $
+	 * $Id: views.php,v 1.60.2.1 2007/05/28 17:21:57 ioguix Exp $
 	 */
 
 	// Include application functions
@@ -12,13 +12,12 @@
 	
 	$action = (isset($_REQUEST['action'])) ? $_REQUEST['action'] : '';
 	if (!isset($msg)) $msg = '';
-	$PHP_SELF = $_SERVER['PHP_SELF'];
 
 	/**
 	 * Ask for select parameters and perform select
 	 */
 	function doSelectRows($confirm, $msg = '') {
-		global $data, $misc;
+		global $data, $misc, $_no_output;  
 		global $lang;
 		global $PHP_SELF;
 
@@ -29,7 +28,7 @@
 
 			$attrs = $data->getTableAttributes($_REQUEST['view']);
 
-			echo "<form action=\"$PHP_SELF\" method=\"get\" name=\"selectform\">\n";
+			echo "<form action=\"$PHP_SELF\" method=\"post\" name=\"selectform\">\n";
 			if ($attrs->recordCount() > 0) {
 				// JavaScript for select all feature
 				echo "<script type=\"text/javascript\">\n";
@@ -80,7 +79,7 @@
 					$attrs->moveNext();
 				}
 				// Select all checkbox
-				echo "<tr><td colspan=\"5\"><input type=\"checkbox\" name=\"selectall\" onClick=\"javascript:selectAll()\" />{$lang['strselectallfields']}</td>";
+				echo "<tr><td colspan=\"5\"><input type=\"checkbox\" id=\"selectall\" name=\"selectall\" onClick=\"javascript:selectAll()\" /><label for=\"selectall\">{$lang['strselectallfields']}</label></td>";
 				echo "</table></p>\n";
 			}
 			else echo "<p>{$lang['strinvalidparam']}</p>\n";
@@ -94,28 +93,29 @@
 			echo "</form>\n";
 		}
 		else {
-			if (!isset($_GET['show'])) $_GET['show'] = array();
-			if (!isset($_GET['values'])) $_GET['values'] = array();
-			if (!isset($_GET['nulls'])) $_GET['nulls'] = array();
+			if (!isset($_POST['show'])) $_POST['show'] = array();
+			if (!isset($_POST['values'])) $_POST['values'] = array();
+			if (!isset($_POST['nulls'])) $_POST['nulls'] = array();
 			
 			// Verify that they haven't supplied a value for unary operators
-			foreach ($_GET['ops'] as $k => $v) {
-				if ($data->selectOps[$v] == 'p' && $_GET['values'][$k] != '') {
+			foreach ($_POST['ops'] as $k => $v) {
+				if ($data->selectOps[$v] == 'p' && $_POST['values'][$k] != '') {
 					doSelectRows(true, $lang['strselectunary']);
 					return;
 				}
 			}
-						
-			if (sizeof($_GET['show']) == 0)
-				doSelectRows(true, $lang['strselectneedscol']);			
+	
+			if (sizeof($_POST['show']) == 0)
+				doSelectRows(true, $lang['strselectneedscol']);
 			else {
 				// Generate query SQL
-				$query = $data->getSelectSQL($_REQUEST['view'], array_keys($_GET['show']),
-					$_GET['values'], $_GET['ops']);
+				$query = $data->getSelectSQL($_REQUEST['view'], array_keys($_POST['show']),
+					$_POST['values'], $_POST['ops']);
 				$_REQUEST['query'] = $query;
-				$_REQUEST['return_url'] = "views.php?action=confselectrows&{$misc->href}&view={$_REQUEST['view']}";
+				$_REQUEST['return_url'] = "views.php?action=confselectrows&amp;{$misc->href}&amp;view={$_REQUEST['view']}";
 				$_REQUEST['return_desc'] = $lang['strback'];
-
+			
+                                $_no_output = true;	
 				include('./display.php');
 				exit;
 			}
@@ -142,7 +142,7 @@
 			echo $misc->form;
 			// Show cascade drop option if supportd
 			if ($data->hasDropBehavior()) {
-				echo "<p><input type=\"checkbox\" name=\"cascade\" /> {$lang['strcascade']}</p>\n";
+				echo "<p><input type=\"checkbox\" id=\"cascade\" name=\"cascade\" /> <label for=\"cascade\">{$lang['strcascade']}</label></p>\n";
 			}
 			echo "<input type=\"submit\" name=\"drop\" value=\"{$lang['strdrop']}\" />\n";
 			echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" />\n";
@@ -595,11 +595,22 @@
 		
 		$attrs = array(
 			'text'   => field('relname'),
-			'icon'   => 'views',
+			'icon'   => 'View',
+			'iconAction' => url('display.php',
+							$reqvars,
+							array('view' => field('relname'))
+						),
 			'toolTip'=> field('relcomment'),
 			'action' => url('redirect.php',
 							$reqvars,
 							array('view' => field('relname'))
+						),
+			'branch' => url('viewproperties.php',
+							$reqvars,
+							array (
+								'action' => 'tree',
+								'view' => field('relname')
+							)
 						)
 		);
 		
